# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class GroupCluster(pulumi.CustomResource):
    cluster_type: pulumi.Output[str]
    created_at: pulumi.Output[str]
    domain: pulumi.Output[str]
    """
    The base domain of the cluster.
    """
    enabled: pulumi.Output[bool]
    """
    Determines if cluster is active or not. Defaults to `true`. This attribute cannot be read.
    """
    environment_scope: pulumi.Output[str]
    """
    The associated environment to the cluster. Defaults to `*`.
    """
    group: pulumi.Output[str]
    """
    The id of the group to add the cluster to.
    """
    kubernetes_api_url: pulumi.Output[str]
    """
    The URL to access the Kubernetes API.
    """
    kubernetes_authorization_type: pulumi.Output[str]
    """
    The cluster authorization type. Valid values are `rbac`, `abac`, `unknown_authorization`. Defaults to `rbac`.
    """
    kubernetes_ca_cert: pulumi.Output[str]
    """
    TLS certificate (needed if API is using a self-signed TLS certificate).
    """
    kubernetes_token: pulumi.Output[str]
    """
    The token to authenticate against Kubernetes.
    """
    managed: pulumi.Output[bool]
    """
    Determines if cluster is managed by gitlab or not. Defaults to `true`. This attribute cannot be read.
    """
    management_project_id: pulumi.Output[str]
    name: pulumi.Output[str]
    """
    The name of cluster.
    """
    platform_type: pulumi.Output[str]
    provider_type: pulumi.Output[str]
    def __init__(__self__, resource_name, opts=None, domain=None, enabled=None, environment_scope=None, group=None, kubernetes_api_url=None, kubernetes_authorization_type=None, kubernetes_ca_cert=None, kubernetes_token=None, managed=None, management_project_id=None, name=None, __props__=None, __name__=None, __opts__=None):
        """
        This resource allows you to create and manage group clusters for your GitLab groups.
        For further information on clusters, consult the [gitlab
        documentation](https://docs.gitlab.com/ce/user/group/clusters/index.html).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        foo = gitlab.Group("foo", path="foo-path")
        bar = gitlab.GroupCluster("bar",
            domain="example.com",
            enabled=True,
            environment_scope="*",
            group=foo.id,
            kubernetes_api_url="https://124.124.124",
            kubernetes_authorization_type="rbac",
            kubernetes_ca_cert="some-cert",
            kubernetes_token="some-token",
            management_cluster_id="123456")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] domain: The base domain of the cluster.
        :param pulumi.Input[bool] enabled: Determines if cluster is active or not. Defaults to `true`. This attribute cannot be read.
        :param pulumi.Input[str] environment_scope: The associated environment to the cluster. Defaults to `*`.
        :param pulumi.Input[str] group: The id of the group to add the cluster to.
        :param pulumi.Input[str] kubernetes_api_url: The URL to access the Kubernetes API.
        :param pulumi.Input[str] kubernetes_authorization_type: The cluster authorization type. Valid values are `rbac`, `abac`, `unknown_authorization`. Defaults to `rbac`.
        :param pulumi.Input[str] kubernetes_ca_cert: TLS certificate (needed if API is using a self-signed TLS certificate).
        :param pulumi.Input[str] kubernetes_token: The token to authenticate against Kubernetes.
        :param pulumi.Input[bool] managed: Determines if cluster is managed by gitlab or not. Defaults to `true`. This attribute cannot be read.
        :param pulumi.Input[str] name: The name of cluster.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['domain'] = domain
            __props__['enabled'] = enabled
            __props__['environment_scope'] = environment_scope
            if group is None:
                raise TypeError("Missing required property 'group'")
            __props__['group'] = group
            if kubernetes_api_url is None:
                raise TypeError("Missing required property 'kubernetes_api_url'")
            __props__['kubernetes_api_url'] = kubernetes_api_url
            __props__['kubernetes_authorization_type'] = kubernetes_authorization_type
            __props__['kubernetes_ca_cert'] = kubernetes_ca_cert
            if kubernetes_token is None:
                raise TypeError("Missing required property 'kubernetes_token'")
            __props__['kubernetes_token'] = kubernetes_token
            __props__['managed'] = managed
            __props__['management_project_id'] = management_project_id
            __props__['name'] = name
            __props__['cluster_type'] = None
            __props__['created_at'] = None
            __props__['platform_type'] = None
            __props__['provider_type'] = None
        super(GroupCluster, __self__).__init__(
            'gitlab:index/groupCluster:GroupCluster',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, cluster_type=None, created_at=None, domain=None, enabled=None, environment_scope=None, group=None, kubernetes_api_url=None, kubernetes_authorization_type=None, kubernetes_ca_cert=None, kubernetes_token=None, managed=None, management_project_id=None, name=None, platform_type=None, provider_type=None):
        """
        Get an existing GroupCluster resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] domain: The base domain of the cluster.
        :param pulumi.Input[bool] enabled: Determines if cluster is active or not. Defaults to `true`. This attribute cannot be read.
        :param pulumi.Input[str] environment_scope: The associated environment to the cluster. Defaults to `*`.
        :param pulumi.Input[str] group: The id of the group to add the cluster to.
        :param pulumi.Input[str] kubernetes_api_url: The URL to access the Kubernetes API.
        :param pulumi.Input[str] kubernetes_authorization_type: The cluster authorization type. Valid values are `rbac`, `abac`, `unknown_authorization`. Defaults to `rbac`.
        :param pulumi.Input[str] kubernetes_ca_cert: TLS certificate (needed if API is using a self-signed TLS certificate).
        :param pulumi.Input[str] kubernetes_token: The token to authenticate against Kubernetes.
        :param pulumi.Input[bool] managed: Determines if cluster is managed by gitlab or not. Defaults to `true`. This attribute cannot be read.
        :param pulumi.Input[str] name: The name of cluster.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["cluster_type"] = cluster_type
        __props__["created_at"] = created_at
        __props__["domain"] = domain
        __props__["enabled"] = enabled
        __props__["environment_scope"] = environment_scope
        __props__["group"] = group
        __props__["kubernetes_api_url"] = kubernetes_api_url
        __props__["kubernetes_authorization_type"] = kubernetes_authorization_type
        __props__["kubernetes_ca_cert"] = kubernetes_ca_cert
        __props__["kubernetes_token"] = kubernetes_token
        __props__["managed"] = managed
        __props__["management_project_id"] = management_project_id
        __props__["name"] = name
        __props__["platform_type"] = platform_type
        __props__["provider_type"] = provider_type
        return GroupCluster(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from .. import utilities, tables

__config__ = pulumi.Config('gitlab')

base_url = __config__.get('baseUrl') or utilities.get_env('GITLAB_BASE_URL')
"""
The GitLab Base API URL
"""

cacert_file = __config__.get('cacertFile')
"""
A file containing the ca certificate to use in case ssl certificate is not from a standard chain
"""

client_cert = __config__.get('clientCert')
"""
File path to client certificate when GitLab instance is behind company proxy. File must contain PEM encoded data.
"""

client_key = __config__.get('clientKey')
"""
File path to client key when GitLab instance is behind company proxy. File must contain PEM encoded data.
"""

insecure = __config__.get('insecure')
"""
Disable SSL verification of API calls
"""

token = __config__.get('token') or utilities.get_env('GITLAB_TOKEN')
"""
The OAuth token used to connect to GitLab.
"""




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class Provider(pulumi.ProviderResource):
    def __init__(__self__, resource_name, opts=None, base_url=None, cacert_file=None, client_cert=None, client_key=None, insecure=None, token=None, __props__=None, __name__=None, __opts__=None):
        """
        The provider type for the gitlab package. By default, resources use package-wide configuration
        settings, however an explicit `Provider` instance may be created and passed during resource
        construction to achieve fine-grained programmatic control over provider settings. See the
        [documentation](https://www.pulumi.com/docs/reference/programming-model/#providers) for more information.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] base_url: The GitLab Base API URL
        :param pulumi.Input[str] cacert_file: A file containing the ca certificate to use in case ssl certificate is not from a standard chain
        :param pulumi.Input[str] client_cert: File path to client certificate when GitLab instance is behind company proxy. File must contain PEM encoded data.
        :param pulumi.Input[str] client_key: File path to client key when GitLab instance is behind company proxy. File must contain PEM encoded data.
        :param pulumi.Input[bool] insecure: Disable SSL verification of API calls
        :param pulumi.Input[str] token: The OAuth token used to connect to GitLab.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if base_url is None:
                base_url = utilities.get_env('GITLAB_BASE_URL')
            __props__['base_url'] = base_url
            __props__['cacert_file'] = cacert_file
            __props__['client_cert'] = client_cert
            __props__['client_key'] = client_key
            __props__['insecure'] = pulumi.Output.from_input(insecure).apply(json.dumps) if insecure is not None else None
            if token is None:
                token = utilities.get_env('GITLAB_TOKEN')
            __props__['token'] = token
        super(Provider, __self__).__init__(
            'gitlab',
            resource_name,
            __props__,
            opts)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class ServiceJira(pulumi.CustomResource):
    active: pulumi.Output[bool]
    comment_on_event_enabled: pulumi.Output[bool]
    """
    Enable comments inside Jira issues on each GitLab event (commit / merge request)
    """
    commit_events: pulumi.Output[bool]
    """
    Enable notifications for commit events
    """
    created_at: pulumi.Output[str]
    jira_issue_transition_id: pulumi.Output[str]
    """
    The ID of a transition that moves issues to a closed state. You can find this number under the JIRA workflow administration (Administration > Issues > Workflows) by selecting View under Operations of the desired workflow of your project. By default, this ID is set to 2.
    """
    merge_requests_events: pulumi.Output[bool]
    """
    Enable notifications for merge request events
    """
    password: pulumi.Output[str]
    """
    The password of the user created to be used with GitLab/JIRA.
    """
    project: pulumi.Output[str]
    """
    ID of the project you want to activate integration on.
    """
    project_key: pulumi.Output[str]
    """
    The short identifier for your JIRA project, all uppercase, e.g., PROJ.
    """
    title: pulumi.Output[str]
    updated_at: pulumi.Output[str]
    url: pulumi.Output[str]
    """
    The URL to the JIRA project which is being linked to this GitLab project. For example, https://jira.example.com.
    """
    username: pulumi.Output[str]
    """
    The username of the user created to be used with GitLab/JIRA.
    """
    def __init__(__self__, resource_name, opts=None, comment_on_event_enabled=None, commit_events=None, jira_issue_transition_id=None, merge_requests_events=None, password=None, project=None, project_key=None, url=None, username=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a ServiceJira resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] comment_on_event_enabled: Enable comments inside Jira issues on each GitLab event (commit / merge request)
        :param pulumi.Input[bool] commit_events: Enable notifications for commit events
        :param pulumi.Input[str] jira_issue_transition_id: The ID of a transition that moves issues to a closed state. You can find this number under the JIRA workflow administration (Administration > Issues > Workflows) by selecting View under Operations of the desired workflow of your project. By default, this ID is set to 2.
        :param pulumi.Input[bool] merge_requests_events: Enable notifications for merge request events
        :param pulumi.Input[str] password: The password of the user created to be used with GitLab/JIRA.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] project_key: The short identifier for your JIRA project, all uppercase, e.g., PROJ.
        :param pulumi.Input[str] url: The URL to the JIRA project which is being linked to this GitLab project. For example, https://jira.example.com.
        :param pulumi.Input[str] username: The username of the user created to be used with GitLab/JIRA.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['comment_on_event_enabled'] = comment_on_event_enabled
            __props__['commit_events'] = commit_events
            __props__['jira_issue_transition_id'] = jira_issue_transition_id
            __props__['merge_requests_events'] = merge_requests_events
            if password is None:
                raise TypeError("Missing required property 'password'")
            __props__['password'] = password
            if project is None:
                raise TypeError("Missing required property 'project'")
            __props__['project'] = project
            __props__['project_key'] = project_key
            if url is None:
                raise TypeError("Missing required property 'url'")
            __props__['url'] = url
            if username is None:
                raise TypeError("Missing required property 'username'")
            __props__['username'] = username
            __props__['active'] = None
            __props__['created_at'] = None
            __props__['title'] = None
            __props__['updated_at'] = None
        super(ServiceJira, __self__).__init__(
            'gitlab:index/serviceJira:ServiceJira',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, active=None, comment_on_event_enabled=None, commit_events=None, created_at=None, jira_issue_transition_id=None, merge_requests_events=None, password=None, project=None, project_key=None, title=None, updated_at=None, url=None, username=None):
        """
        Get an existing ServiceJira resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] comment_on_event_enabled: Enable comments inside Jira issues on each GitLab event (commit / merge request)
        :param pulumi.Input[bool] commit_events: Enable notifications for commit events
        :param pulumi.Input[str] jira_issue_transition_id: The ID of a transition that moves issues to a closed state. You can find this number under the JIRA workflow administration (Administration > Issues > Workflows) by selecting View under Operations of the desired workflow of your project. By default, this ID is set to 2.
        :param pulumi.Input[bool] merge_requests_events: Enable notifications for merge request events
        :param pulumi.Input[str] password: The password of the user created to be used with GitLab/JIRA.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] project_key: The short identifier for your JIRA project, all uppercase, e.g., PROJ.
        :param pulumi.Input[str] url: The URL to the JIRA project which is being linked to this GitLab project. For example, https://jira.example.com.
        :param pulumi.Input[str] username: The username of the user created to be used with GitLab/JIRA.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["active"] = active
        __props__["comment_on_event_enabled"] = comment_on_event_enabled
        __props__["commit_events"] = commit_events
        __props__["created_at"] = created_at
        __props__["jira_issue_transition_id"] = jira_issue_transition_id
        __props__["merge_requests_events"] = merge_requests_events
        __props__["password"] = password
        __props__["project"] = project
        __props__["project_key"] = project_key
        __props__["title"] = title
        __props__["updated_at"] = updated_at
        __props__["url"] = url
        __props__["username"] = username
        return ServiceJira(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class DeployKeyEnable(pulumi.CustomResource):
    can_push: pulumi.Output[bool]
    key: pulumi.Output[str]
    key_id: pulumi.Output[str]
    """
    The Gitlab key id for the pre-existing deploy key
    """
    project: pulumi.Output[str]
    """
    The name or id of the project to add the deploy key to.
    """
    title: pulumi.Output[str]
    def __init__(__self__, resource_name, opts=None, can_push=None, key=None, key_id=None, project=None, title=None, __props__=None, __name__=None, __opts__=None):
        """
        This resource allows you to enable pre-existing deploy keys for your GitLab projects.

        **the GITLAB KEY_ID for the deploy key must be known**

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # A repo to host the deployment key
        parent_project = gitlab.Project("parentProject")
        # A second repo to use the deployment key from the parent project
        foo_project = gitlab.Project("fooProject")
        # Upload a deployment key for the parent repo
        parent_deploy_key = gitlab.DeployKey("parentDeployKey",
            key="ssh-rsa AAAA...",
            project=parent_project.id,
            title="Example deploy key")
        # Enable the deployment key on the second repo
        foo_deploy_key_enable = gitlab.DeployKeyEnable("fooDeployKeyEnable",
            key_id=parent_deploy_key.id,
            project=foo_project.id)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] key_id: The Gitlab key id for the pre-existing deploy key
        :param pulumi.Input[str] project: The name or id of the project to add the deploy key to.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['can_push'] = can_push
            __props__['key'] = key
            if key_id is None:
                raise TypeError("Missing required property 'key_id'")
            __props__['key_id'] = key_id
            if project is None:
                raise TypeError("Missing required property 'project'")
            __props__['project'] = project
            __props__['title'] = title
        super(DeployKeyEnable, __self__).__init__(
            'gitlab:index/deployKeyEnable:DeployKeyEnable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, can_push=None, key=None, key_id=None, project=None, title=None):
        """
        Get an existing DeployKeyEnable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] key_id: The Gitlab key id for the pre-existing deploy key
        :param pulumi.Input[str] project: The name or id of the project to add the deploy key to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["can_push"] = can_push
        __props__["key"] = key
        __props__["key_id"] = key_id
        __props__["project"] = project
        __props__["title"] = title
        return DeployKeyEnable(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class ProjectVariable(pulumi.CustomResource):
    environment_scope: pulumi.Output[str]
    """
    The environment_scope of the variable
    """
    key: pulumi.Output[str]
    """
    The name of the variable.
    """
    masked: pulumi.Output[bool]
    """
    If set to `true`, the variable will be masked if it would have been written to the logs. Defaults to `false`.
    """
    project: pulumi.Output[str]
    """
    The name or id of the project to add the hook to.
    """
    protected: pulumi.Output[bool]
    """
    If set to `true`, the variable will be passed only to pipelines running on protected branches and tags. Defaults to `false`.
    """
    value: pulumi.Output[str]
    """
    The value of the variable.
    """
    variable_type: pulumi.Output[str]
    """
    The type of a variable. Available types are: env_var (default) and file.
    """
    def __init__(__self__, resource_name, opts=None, environment_scope=None, key=None, masked=None, project=None, protected=None, value=None, variable_type=None, __props__=None, __name__=None, __opts__=None):
        """
        This resource allows you to create and manage CI/CD variables for your GitLab projects.
        For further information on variables, consult the [gitlab
        documentation](https://docs.gitlab.com/ce/ci/variables/README.html#variables).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.ProjectVariable("example",
            key="project_variable_key",
            project="12345",
            protected=False,
            value="project_variable_value")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] environment_scope: The environment_scope of the variable
        :param pulumi.Input[str] key: The name of the variable.
        :param pulumi.Input[bool] masked: If set to `true`, the variable will be masked if it would have been written to the logs. Defaults to `false`.
        :param pulumi.Input[str] project: The name or id of the project to add the hook to.
        :param pulumi.Input[bool] protected: If set to `true`, the variable will be passed only to pipelines running on protected branches and tags. Defaults to `false`.
        :param pulumi.Input[str] value: The value of the variable.
        :param pulumi.Input[str] variable_type: The type of a variable. Available types are: env_var (default) and file.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['environment_scope'] = environment_scope
            if key is None:
                raise TypeError("Missing required property 'key'")
            __props__['key'] = key
            __props__['masked'] = masked
            if project is None:
                raise TypeError("Missing required property 'project'")
            __props__['project'] = project
            __props__['protected'] = protected
            if value is None:
                raise TypeError("Missing required property 'value'")
            __props__['value'] = value
            __props__['variable_type'] = variable_type
        super(ProjectVariable, __self__).__init__(
            'gitlab:index/projectVariable:ProjectVariable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, environment_scope=None, key=None, masked=None, project=None, protected=None, value=None, variable_type=None):
        """
        Get an existing ProjectVariable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] environment_scope: The environment_scope of the variable
        :param pulumi.Input[str] key: The name of the variable.
        :param pulumi.Input[bool] masked: If set to `true`, the variable will be masked if it would have been written to the logs. Defaults to `false`.
        :param pulumi.Input[str] project: The name or id of the project to add the hook to.
        :param pulumi.Input[bool] protected: If set to `true`, the variable will be passed only to pipelines running on protected branches and tags. Defaults to `false`.
        :param pulumi.Input[str] value: The value of the variable.
        :param pulumi.Input[str] variable_type: The type of a variable. Available types are: env_var (default) and file.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["environment_scope"] = environment_scope
        __props__["key"] = key
        __props__["masked"] = masked
        __props__["project"] = project
        __props__["protected"] = protected
        __props__["value"] = value
        __props__["variable_type"] = variable_type
        return ProjectVariable(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "access_level": "accessLevel",
    "approvals_before_merge": "approvalsBeforeMerge",
    "author_email_regex": "authorEmailRegex",
    "branch_name_regex": "branchNameRegex",
    "branches_to_be_notified": "branchesToBeNotified",
    "can_create_group": "canCreateGroup",
    "can_push": "canPush",
    "cluster_type": "clusterType",
    "comment_on_event_enabled": "commentOnEventEnabled",
    "commit_events": "commitEvents",
    "commit_message_regex": "commitMessageRegex",
    "confidential_issue_channel": "confidentialIssueChannel",
    "confidential_issues_events": "confidentialIssuesEvents",
    "confidential_note_events": "confidentialNoteEvents",
    "container_registry_enabled": "containerRegistryEnabled",
    "create_access_level": "createAccessLevel",
    "created_at": "createdAt",
    "cron_timezone": "cronTimezone",
    "default_branch": "defaultBranch",
    "deny_delete_tag": "denyDeleteTag",
    "enable_ssl_verification": "enableSslVerification",
    "environment_scope": "environmentScope",
    "expires_at": "expiresAt",
    "file_name_regex": "fileNameRegex",
    "full_name": "fullName",
    "full_path": "fullPath",
    "group_id": "groupId",
    "http_url_to_repo": "httpUrlToRepo",
    "initialize_with_readme": "initializeWithReadme",
    "is_admin": "isAdmin",
    "is_external": "isExternal",
    "issue_channel": "issueChannel",
    "issues_enabled": "issuesEnabled",
    "issues_events": "issuesEvents",
    "jira_issue_transition_id": "jiraIssueTransitionId",
    "job_events": "jobEvents",
    "key_id": "keyId",
    "kubernetes_api_url": "kubernetesApiUrl",
    "kubernetes_authorization_type": "kubernetesAuthorizationType",
    "kubernetes_ca_cert": "kubernetesCaCert",
    "kubernetes_namespace": "kubernetesNamespace",
    "kubernetes_token": "kubernetesToken",
    "ldap_provider": "ldapProvider",
    "lfs_enabled": "lfsEnabled",
    "management_project_id": "managementProjectId",
    "max_file_size": "maxFileSize",
    "member_check": "memberCheck",
    "merge_access_level": "mergeAccessLevel",
    "merge_method": "mergeMethod",
    "merge_request_channel": "mergeRequestChannel",
    "merge_requests_enabled": "mergeRequestsEnabled",
    "merge_requests_events": "mergeRequestsEvents",
    "namespace_id": "namespaceId",
    "note_channel": "noteChannel",
    "note_events": "noteEvents",
    "notify_only_broken_pipelines": "notifyOnlyBrokenPipelines",
    "notify_only_default_branch": "notifyOnlyDefaultBranch",
    "only_allow_merge_if_all_discussions_are_resolved": "onlyAllowMergeIfAllDiscussionsAreResolved",
    "only_allow_merge_if_pipeline_succeeds": "onlyAllowMergeIfPipelineSucceeds",
    "parent_id": "parentId",
    "pipeline_channel": "pipelineChannel",
    "pipeline_events": "pipelineEvents",
    "pipeline_schedule_id": "pipelineScheduleId",
    "pipelines_enabled": "pipelinesEnabled",
    "platform_type": "platformType",
    "prevent_secrets": "preventSecrets",
    "project_id": "projectId",
    "project_key": "projectKey",
    "projects_limit": "projectsLimit",
    "provider_type": "providerType",
    "push_access_level": "pushAccessLevel",
    "push_channel": "pushChannel",
    "push_events": "pushEvents",
    "remove_source_branch_after_merge": "removeSourceBranchAfterMerge",
    "repository_url": "repositoryUrl",
    "request_access_enabled": "requestAccessEnabled",
    "reset_password": "resetPassword",
    "runners_token": "runnersToken",
    "shared_runners_enabled": "sharedRunnersEnabled",
    "shared_with_groups": "sharedWithGroups",
    "skip_confirmation": "skipConfirmation",
    "snippets_enabled": "snippetsEnabled",
    "ssh_url_to_repo": "sshUrlToRepo",
    "static_context": "staticContext",
    "tag_push_channel": "tagPushChannel",
    "tag_push_events": "tagPushEvents",
    "updated_at": "updatedAt",
    "user_id": "userId",
    "variable_type": "variableType",
    "visibility_level": "visibilityLevel",
    "web_url": "webUrl",
    "wiki_enabled": "wikiEnabled",
    "wiki_page_channel": "wikiPageChannel",
    "wiki_page_events": "wikiPageEvents",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "accessLevel": "access_level",
    "approvalsBeforeMerge": "approvals_before_merge",
    "authorEmailRegex": "author_email_regex",
    "branchNameRegex": "branch_name_regex",
    "branchesToBeNotified": "branches_to_be_notified",
    "canCreateGroup": "can_create_group",
    "canPush": "can_push",
    "clusterType": "cluster_type",
    "commentOnEventEnabled": "comment_on_event_enabled",
    "commitEvents": "commit_events",
    "commitMessageRegex": "commit_message_regex",
    "confidentialIssueChannel": "confidential_issue_channel",
    "confidentialIssuesEvents": "confidential_issues_events",
    "confidentialNoteEvents": "confidential_note_events",
    "containerRegistryEnabled": "container_registry_enabled",
    "createAccessLevel": "create_access_level",
    "createdAt": "created_at",
    "cronTimezone": "cron_timezone",
    "defaultBranch": "default_branch",
    "denyDeleteTag": "deny_delete_tag",
    "enableSslVerification": "enable_ssl_verification",
    "environmentScope": "environment_scope",
    "expiresAt": "expires_at",
    "fileNameRegex": "file_name_regex",
    "fullName": "full_name",
    "fullPath": "full_path",
    "groupId": "group_id",
    "httpUrlToRepo": "http_url_to_repo",
    "initializeWithReadme": "initialize_with_readme",
    "isAdmin": "is_admin",
    "isExternal": "is_external",
    "issueChannel": "issue_channel",
    "issuesEnabled": "issues_enabled",
    "issuesEvents": "issues_events",
    "jiraIssueTransitionId": "jira_issue_transition_id",
    "jobEvents": "job_events",
    "keyId": "key_id",
    "kubernetesApiUrl": "kubernetes_api_url",
    "kubernetesAuthorizationType": "kubernetes_authorization_type",
    "kubernetesCaCert": "kubernetes_ca_cert",
    "kubernetesNamespace": "kubernetes_namespace",
    "kubernetesToken": "kubernetes_token",
    "ldapProvider": "ldap_provider",
    "lfsEnabled": "lfs_enabled",
    "managementProjectId": "management_project_id",
    "maxFileSize": "max_file_size",
    "memberCheck": "member_check",
    "mergeAccessLevel": "merge_access_level",
    "mergeMethod": "merge_method",
    "mergeRequestChannel": "merge_request_channel",
    "mergeRequestsEnabled": "merge_requests_enabled",
    "mergeRequestsEvents": "merge_requests_events",
    "namespaceId": "namespace_id",
    "noteChannel": "note_channel",
    "noteEvents": "note_events",
    "notifyOnlyBrokenPipelines": "notify_only_broken_pipelines",
    "notifyOnlyDefaultBranch": "notify_only_default_branch",
    "onlyAllowMergeIfAllDiscussionsAreResolved": "only_allow_merge_if_all_discussions_are_resolved",
    "onlyAllowMergeIfPipelineSucceeds": "only_allow_merge_if_pipeline_succeeds",
    "parentId": "parent_id",
    "pipelineChannel": "pipeline_channel",
    "pipelineEvents": "pipeline_events",
    "pipelineScheduleId": "pipeline_schedule_id",
    "pipelinesEnabled": "pipelines_enabled",
    "platformType": "platform_type",
    "preventSecrets": "prevent_secrets",
    "projectId": "project_id",
    "projectKey": "project_key",
    "projectsLimit": "projects_limit",
    "providerType": "provider_type",
    "pushAccessLevel": "push_access_level",
    "pushChannel": "push_channel",
    "pushEvents": "push_events",
    "removeSourceBranchAfterMerge": "remove_source_branch_after_merge",
    "repositoryUrl": "repository_url",
    "requestAccessEnabled": "request_access_enabled",
    "resetPassword": "reset_password",
    "runnersToken": "runners_token",
    "sharedRunnersEnabled": "shared_runners_enabled",
    "sharedWithGroups": "shared_with_groups",
    "skipConfirmation": "skip_confirmation",
    "snippetsEnabled": "snippets_enabled",
    "sshUrlToRepo": "ssh_url_to_repo",
    "staticContext": "static_context",
    "tagPushChannel": "tag_push_channel",
    "tagPushEvents": "tag_push_events",
    "updatedAt": "updated_at",
    "userId": "user_id",
    "variableType": "variable_type",
    "visibilityLevel": "visibility_level",
    "webUrl": "web_url",
    "wikiEnabled": "wiki_enabled",
    "wikiPageChannel": "wiki_page_channel",
    "wikiPageEvents": "wiki_page_events",
}



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class ProjectPushRules(pulumi.CustomResource):
    author_email_regex: pulumi.Output[str]
    """
    All commit author emails must match this regex, e.g. "@my-company.com$"
    """
    branch_name_regex: pulumi.Output[str]
    """
    All branch names must match this regex, e.g. "(feature|hotfix)\/*"
    """
    commit_message_regex: pulumi.Output[str]
    """
    All commit messages must match this regex, e.g. "Fixed \d+\..*"
    """
    deny_delete_tag: pulumi.Output[bool]
    """
    Deny deleting a tag
    """
    file_name_regex: pulumi.Output[str]
    """
    All commited filenames must not match this regex, e.g. "(jar|exe)$"
    """
    max_file_size: pulumi.Output[float]
    """
    Maximum file size (MB)
    """
    member_check: pulumi.Output[bool]
    """
    Restrict commits by author (email) to existing GitLab users
    """
    prevent_secrets: pulumi.Output[bool]
    """
    GitLab will reject any files that are likely to contain secrets
    """
    project: pulumi.Output[str]
    """
    The name or id of the project to add the push rules to.
    """
    def __init__(__self__, resource_name, opts=None, author_email_regex=None, branch_name_regex=None, commit_message_regex=None, deny_delete_tag=None, file_name_regex=None, max_file_size=None, member_check=None, prevent_secrets=None, project=None, __props__=None, __name__=None, __opts__=None):
        """
        This resource allows you to create and manage push rules for your GitLab projects.
        For further information on push rules, consult the [gitlab
        documentation](https://docs.gitlab.com/ce/push_rules/push_rules.html#push-rules).

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] author_email_regex: All commit author emails must match this regex, e.g. "@my-company.com$"
        :param pulumi.Input[str] branch_name_regex: All branch names must match this regex, e.g. "(feature|hotfix)\/*"
        :param pulumi.Input[str] commit_message_regex: All commit messages must match this regex, e.g. "Fixed \d+\..*"
        :param pulumi.Input[bool] deny_delete_tag: Deny deleting a tag
        :param pulumi.Input[str] file_name_regex: All commited filenames must not match this regex, e.g. "(jar|exe)$"
        :param pulumi.Input[float] max_file_size: Maximum file size (MB)
        :param pulumi.Input[bool] member_check: Restrict commits by author (email) to existing GitLab users
        :param pulumi.Input[bool] prevent_secrets: GitLab will reject any files that are likely to contain secrets
        :param pulumi.Input[str] project: The name or id of the project to add the push rules to.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['author_email_regex'] = author_email_regex
            __props__['branch_name_regex'] = branch_name_regex
            __props__['commit_message_regex'] = commit_message_regex
            __props__['deny_delete_tag'] = deny_delete_tag
            __props__['file_name_regex'] = file_name_regex
            __props__['max_file_size'] = max_file_size
            __props__['member_check'] = member_check
            __props__['prevent_secrets'] = prevent_secrets
            if project is None:
                raise TypeError("Missing required property 'project'")
            __props__['project'] = project
        super(ProjectPushRules, __self__).__init__(
            'gitlab:index/projectPushRules:ProjectPushRules',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, author_email_regex=None, branch_name_regex=None, commit_message_regex=None, deny_delete_tag=None, file_name_regex=None, max_file_size=None, member_check=None, prevent_secrets=None, project=None):
        """
        Get an existing ProjectPushRules resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] author_email_regex: All commit author emails must match this regex, e.g. "@my-company.com$"
        :param pulumi.Input[str] branch_name_regex: All branch names must match this regex, e.g. "(feature|hotfix)\/*"
        :param pulumi.Input[str] commit_message_regex: All commit messages must match this regex, e.g. "Fixed \d+\..*"
        :param pulumi.Input[bool] deny_delete_tag: Deny deleting a tag
        :param pulumi.Input[str] file_name_regex: All commited filenames must not match this regex, e.g. "(jar|exe)$"
        :param pulumi.Input[float] max_file_size: Maximum file size (MB)
        :param pulumi.Input[bool] member_check: Restrict commits by author (email) to existing GitLab users
        :param pulumi.Input[bool] prevent_secrets: GitLab will reject any files that are likely to contain secrets
        :param pulumi.Input[str] project: The name or id of the project to add the push rules to.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["author_email_regex"] = author_email_regex
        __props__["branch_name_regex"] = branch_name_regex
        __props__["commit_message_regex"] = commit_message_regex
        __props__["deny_delete_tag"] = deny_delete_tag
        __props__["file_name_regex"] = file_name_regex
        __props__["max_file_size"] = max_file_size
        __props__["member_check"] = member_check
        __props__["prevent_secrets"] = prevent_secrets
        __props__["project"] = project
        return ProjectPushRules(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class ServiceGithub(pulumi.CustomResource):
    active: pulumi.Output[bool]
    created_at: pulumi.Output[str]
    project: pulumi.Output[str]
    """
    ID of the project you want to activate integration on.
    """
    repository_url: pulumi.Output[str]
    static_context: pulumi.Output[bool]
    """
    Append instance name instead of branch to the status. Must enable to set a GitLab status check as _required_ in GitHub. See [Static / dynamic status check names] to learn more.
    """
    title: pulumi.Output[str]
    token: pulumi.Output[str]
    """
    A GitHub personal access token with at least `repo:status` scope.
    """
    updated_at: pulumi.Output[str]
    def __init__(__self__, resource_name, opts=None, project=None, repository_url=None, static_context=None, token=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a ServiceGithub resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[bool] static_context: Append instance name instead of branch to the status. Must enable to set a GitLab status check as _required_ in GitHub. See [Static / dynamic status check names] to learn more.
        :param pulumi.Input[str] token: A GitHub personal access token with at least `repo:status` scope.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if project is None:
                raise TypeError("Missing required property 'project'")
            __props__['project'] = project
            if repository_url is None:
                raise TypeError("Missing required property 'repository_url'")
            __props__['repository_url'] = repository_url
            __props__['static_context'] = static_context
            if token is None:
                raise TypeError("Missing required property 'token'")
            __props__['token'] = token
            __props__['active'] = None
            __props__['created_at'] = None
            __props__['title'] = None
            __props__['updated_at'] = None
        super(ServiceGithub, __self__).__init__(
            'gitlab:index/serviceGithub:ServiceGithub',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, active=None, created_at=None, project=None, repository_url=None, static_context=None, title=None, token=None, updated_at=None):
        """
        Get an existing ServiceGithub resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[bool] static_context: Append instance name instead of branch to the status. Must enable to set a GitLab status check as _required_ in GitHub. See [Static / dynamic status check names] to learn more.
        :param pulumi.Input[str] token: A GitHub personal access token with at least `repo:status` scope.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["active"] = active
        __props__["created_at"] = created_at
        __props__["project"] = project
        __props__["repository_url"] = repository_url
        __props__["static_context"] = static_context
        __props__["title"] = title
        __props__["token"] = token
        __props__["updated_at"] = updated_at
        return ServiceGithub(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class ServiceSlack(pulumi.CustomResource):
    branches_to_be_notified: pulumi.Output[str]
    """
    Branches to send notifications for. Valid options are "all", "default", "protected", and "default_and_protected".
    """
    confidential_issue_channel: pulumi.Output[str]
    """
    The name of the channel to receive confidential issue events notifications.
    """
    confidential_issues_events: pulumi.Output[bool]
    """
    Enable notifications for confidential issues events.
    """
    confidential_note_events: pulumi.Output[bool]
    """
    Enable notifications for confidential note events.
    """
    issue_channel: pulumi.Output[str]
    """
    The name of the channel to receive issue events notifications.
    """
    issues_events: pulumi.Output[bool]
    """
    Enable notifications for issues events.
    """
    job_events: pulumi.Output[bool]
    merge_request_channel: pulumi.Output[str]
    """
    The name of the channel to receive merge request events notifications.
    """
    merge_requests_events: pulumi.Output[bool]
    """
    Enable notifications for merge requests events.
    """
    note_channel: pulumi.Output[str]
    """
    The name of the channel to receive note events notifications.
    """
    note_events: pulumi.Output[bool]
    """
    Enable notifications for note events.
    """
    notify_only_broken_pipelines: pulumi.Output[bool]
    """
    Send notifications for broken pipelines.
    """
    notify_only_default_branch: pulumi.Output[bool]
    """
    DEPRECATED: This parameter has been replaced with `branches_to_be_notified`.
    """
    pipeline_channel: pulumi.Output[str]
    """
    The name of the channel to receive pipeline events notifications.
    """
    pipeline_events: pulumi.Output[bool]
    """
    Enable notifications for pipeline events.
    """
    project: pulumi.Output[str]
    """
    ID of the project you want to activate integration on.
    """
    push_channel: pulumi.Output[str]
    """
    The name of the channel to receive push events notifications.
    """
    push_events: pulumi.Output[bool]
    """
    Enable notifications for push events.
    """
    tag_push_channel: pulumi.Output[str]
    """
    The name of the channel to receive tag push events notifications.
    """
    tag_push_events: pulumi.Output[bool]
    """
    Enable notifications for tag push events.
    """
    username: pulumi.Output[str]
    """
    Username to use.
    """
    webhook: pulumi.Output[str]
    """
    Webhook URL (ex.: https://hooks.slack.com/services/...)
    """
    wiki_page_channel: pulumi.Output[str]
    """
    The name of the channel to receive wiki page events notifications.
    """
    wiki_page_events: pulumi.Output[bool]
    """
    Enable notifications for wiki page events.
    """
    def __init__(__self__, resource_name, opts=None, branches_to_be_notified=None, confidential_issue_channel=None, confidential_issues_events=None, confidential_note_events=None, issue_channel=None, issues_events=None, merge_request_channel=None, merge_requests_events=None, note_channel=None, note_events=None, notify_only_broken_pipelines=None, notify_only_default_branch=None, pipeline_channel=None, pipeline_events=None, project=None, push_channel=None, push_events=None, tag_push_channel=None, tag_push_events=None, username=None, webhook=None, wiki_page_channel=None, wiki_page_events=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a ServiceSlack resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] branches_to_be_notified: Branches to send notifications for. Valid options are "all", "default", "protected", and "default_and_protected".
        :param pulumi.Input[str] confidential_issue_channel: The name of the channel to receive confidential issue events notifications.
        :param pulumi.Input[bool] confidential_issues_events: Enable notifications for confidential issues events.
        :param pulumi.Input[bool] confidential_note_events: Enable notifications for confidential note events.
        :param pulumi.Input[str] issue_channel: The name of the channel to receive issue events notifications.
        :param pulumi.Input[bool] issues_events: Enable notifications for issues events.
        :param pulumi.Input[str] merge_request_channel: The name of the channel to receive merge request events notifications.
        :param pulumi.Input[bool] merge_requests_events: Enable notifications for merge requests events.
        :param pulumi.Input[str] note_channel: The name of the channel to receive note events notifications.
        :param pulumi.Input[bool] note_events: Enable notifications for note events.
        :param pulumi.Input[bool] notify_only_broken_pipelines: Send notifications for broken pipelines.
        :param pulumi.Input[bool] notify_only_default_branch: DEPRECATED: This parameter has been replaced with `branches_to_be_notified`.
        :param pulumi.Input[str] pipeline_channel: The name of the channel to receive pipeline events notifications.
        :param pulumi.Input[bool] pipeline_events: Enable notifications for pipeline events.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] push_channel: The name of the channel to receive push events notifications.
        :param pulumi.Input[bool] push_events: Enable notifications for push events.
        :param pulumi.Input[str] tag_push_channel: The name of the channel to receive tag push events notifications.
        :param pulumi.Input[bool] tag_push_events: Enable notifications for tag push events.
        :param pulumi.Input[str] username: Username to use.
        :param pulumi.Input[str] webhook: Webhook URL (ex.: https://hooks.slack.com/services/...)
        :param pulumi.Input[str] wiki_page_channel: The name of the channel to receive wiki page events notifications.
        :param pulumi.Input[bool] wiki_page_events: Enable notifications for wiki page events.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['branches_to_be_notified'] = branches_to_be_notified
            __props__['confidential_issue_channel'] = confidential_issue_channel
            __props__['confidential_issues_events'] = confidential_issues_events
            __props__['confidential_note_events'] = confidential_note_events
            __props__['issue_channel'] = issue_channel
            __props__['issues_events'] = issues_events
            __props__['merge_request_channel'] = merge_request_channel
            __props__['merge_requests_events'] = merge_requests_events
            __props__['note_channel'] = note_channel
            __props__['note_events'] = note_events
            __props__['notify_only_broken_pipelines'] = notify_only_broken_pipelines
            if notify_only_default_branch is not None:
                warnings.warn("use 'branches_to_be_notified' argument instead", DeprecationWarning)
                pulumi.log.warn("notify_only_default_branch is deprecated: use 'branches_to_be_notified' argument instead")
            __props__['notify_only_default_branch'] = notify_only_default_branch
            __props__['pipeline_channel'] = pipeline_channel
            __props__['pipeline_events'] = pipeline_events
            if project is None:
                raise TypeError("Missing required property 'project'")
            __props__['project'] = project
            __props__['push_channel'] = push_channel
            __props__['push_events'] = push_events
            __props__['tag_push_channel'] = tag_push_channel
            __props__['tag_push_events'] = tag_push_events
            __props__['username'] = username
            if webhook is None:
                raise TypeError("Missing required property 'webhook'")
            __props__['webhook'] = webhook
            __props__['wiki_page_channel'] = wiki_page_channel
            __props__['wiki_page_events'] = wiki_page_events
            __props__['job_events'] = None
        super(ServiceSlack, __self__).__init__(
            'gitlab:index/serviceSlack:ServiceSlack',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, branches_to_be_notified=None, confidential_issue_channel=None, confidential_issues_events=None, confidential_note_events=None, issue_channel=None, issues_events=None, job_events=None, merge_request_channel=None, merge_requests_events=None, note_channel=None, note_events=None, notify_only_broken_pipelines=None, notify_only_default_branch=None, pipeline_channel=None, pipeline_events=None, project=None, push_channel=None, push_events=None, tag_push_channel=None, tag_push_events=None, username=None, webhook=None, wiki_page_channel=None, wiki_page_events=None):
        """
        Get an existing ServiceSlack resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] branches_to_be_notified: Branches to send notifications for. Valid options are "all", "default", "protected", and "default_and_protected".
        :param pulumi.Input[str] confidential_issue_channel: The name of the channel to receive confidential issue events notifications.
        :param pulumi.Input[bool] confidential_issues_events: Enable notifications for confidential issues events.
        :param pulumi.Input[bool] confidential_note_events: Enable notifications for confidential note events.
        :param pulumi.Input[str] issue_channel: The name of the channel to receive issue events notifications.
        :param pulumi.Input[bool] issues_events: Enable notifications for issues events.
        :param pulumi.Input[str] merge_request_channel: The name of the channel to receive merge request events notifications.
        :param pulumi.Input[bool] merge_requests_events: Enable notifications for merge requests events.
        :param pulumi.Input[str] note_channel: The name of the channel to receive note events notifications.
        :param pulumi.Input[bool] note_events: Enable notifications for note events.
        :param pulumi.Input[bool] notify_only_broken_pipelines: Send notifications for broken pipelines.
        :param pulumi.Input[bool] notify_only_default_branch: DEPRECATED: This parameter has been replaced with `branches_to_be_notified`.
        :param pulumi.Input[str] pipeline_channel: The name of the channel to receive pipeline events notifications.
        :param pulumi.Input[bool] pipeline_events: Enable notifications for pipeline events.
        :param pulumi.Input[str] project: ID of the project you want to activate integration on.
        :param pulumi.Input[str] push_channel: The name of the channel to receive push events notifications.
        :param pulumi.Input[bool] push_events: Enable notifications for push events.
        :param pulumi.Input[str] tag_push_channel: The name of the channel to receive tag push events notifications.
        :param pulumi.Input[bool] tag_push_events: Enable notifications for tag push events.
        :param pulumi.Input[str] username: Username to use.
        :param pulumi.Input[str] webhook: Webhook URL (ex.: https://hooks.slack.com/services/...)
        :param pulumi.Input[str] wiki_page_channel: The name of the channel to receive wiki page events notifications.
        :param pulumi.Input[bool] wiki_page_events: Enable notifications for wiki page events.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["branches_to_be_notified"] = branches_to_be_notified
        __props__["confidential_issue_channel"] = confidential_issue_channel
        __props__["confidential_issues_events"] = confidential_issues_events
        __props__["confidential_note_events"] = confidential_note_events
        __props__["issue_channel"] = issue_channel
        __props__["issues_events"] = issues_events
        __props__["job_events"] = job_events
        __props__["merge_request_channel"] = merge_request_channel
        __props__["merge_requests_events"] = merge_requests_events
        __props__["note_channel"] = note_channel
        __props__["note_events"] = note_events
        __props__["notify_only_broken_pipelines"] = notify_only_broken_pipelines
        __props__["notify_only_default_branch"] = notify_only_default_branch
        __props__["pipeline_channel"] = pipeline_channel
        __props__["pipeline_events"] = pipeline_events
        __props__["project"] = project
        __props__["push_channel"] = push_channel
        __props__["push_events"] = push_events
        __props__["tag_push_channel"] = tag_push_channel
        __props__["tag_push_events"] = tag_push_events
        __props__["username"] = username
        __props__["webhook"] = webhook
        __props__["wiki_page_channel"] = wiki_page_channel
        __props__["wiki_page_events"] = wiki_page_events
        return ServiceSlack(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class Project(pulumi.CustomResource):
    approvals_before_merge: pulumi.Output[float]
    """
    Number of merge request approvals required for merging. Default is 0.
    """
    archived: pulumi.Output[bool]
    """
    Whether the project is in read-only mode (archived). Repositories can be archived/unarchived by toggling this parameter.
    """
    container_registry_enabled: pulumi.Output[bool]
    """
    Enable container registry for the project.
    """
    default_branch: pulumi.Output[str]
    """
    The default branch for the project.
    """
    description: pulumi.Output[str]
    """
    A description of the project.
    """
    http_url_to_repo: pulumi.Output[str]
    """
    URL that can be provided to `git clone` to clone the
    repository via HTTP.
    """
    initialize_with_readme: pulumi.Output[bool]
    """
    Create master branch with first commit containing a README.md file.
    """
    issues_enabled: pulumi.Output[bool]
    """
    Enable issue tracking for the project.
    """
    lfs_enabled: pulumi.Output[bool]
    """
    Enable LFS for the project.
    """
    merge_method: pulumi.Output[str]
    """
    Set to `ff` to create fast-forward merges
    Valid values are `merge`, `rebase_merge`, `ff`
    Repositories are created with `merge` by default
    """
    merge_requests_enabled: pulumi.Output[bool]
    """
    Enable merge requests for the project.
    """
    name: pulumi.Output[str]
    """
    The name of the project.
    """
    namespace_id: pulumi.Output[float]
    """
    The namespace (group or user) of the project. Defaults to your user.
    See `Group` for an example.
    """
    only_allow_merge_if_all_discussions_are_resolved: pulumi.Output[bool]
    """
    Set to true if you want allow merges only if all discussions are resolved.
    """
    only_allow_merge_if_pipeline_succeeds: pulumi.Output[bool]
    """
    Set to true if you want allow merges only if a pipeline succeeds.
    """
    path: pulumi.Output[str]
    """
    The path of the repository.
    """
    pipelines_enabled: pulumi.Output[bool]
    """
    Enable pipelines for the project.
    """
    remove_source_branch_after_merge: pulumi.Output[bool]
    """
    Enable `Delete source branch` option by default for all new merge requests.
    """
    request_access_enabled: pulumi.Output[bool]
    """
    Allow users to request member access.
    """
    runners_token: pulumi.Output[str]
    """
    Registration token to use during runner setup.
    """
    shared_runners_enabled: pulumi.Output[bool]
    """
    Enable shared runners for this project.
    """
    shared_with_groups: pulumi.Output[list]
    """
    Enable sharing the project with a list of groups (maps).

      * `groupAccessLevel` (`str`) - Group's sharing permissions. See [group members permission][group_members_permissions] for more info.
        Valid values are `guest`, `reporter`, `developer`, `master`.
      * `group_id` (`float`) - Group id of the group you want to share the project with.
      * `groupName` (`str`) - Group's name.
    """
    snippets_enabled: pulumi.Output[bool]
    """
    Enable snippets for the project.
    """
    ssh_url_to_repo: pulumi.Output[str]
    """
    URL that can be provided to `git clone` to clone the
    repository via SSH.
    """
    tags: pulumi.Output[list]
    """
    Tags (topics) of the project.
    """
    visibility_level: pulumi.Output[str]
    """
    Set to `public` to create a public project.
    Valid values are `private`, `internal`, `public`.
    Repositories are created as private by default.
    """
    web_url: pulumi.Output[str]
    """
    URL that can be used to find the project in a browser.
    """
    wiki_enabled: pulumi.Output[bool]
    """
    Enable wiki for the project.
    """
    def __init__(__self__, resource_name, opts=None, approvals_before_merge=None, archived=None, container_registry_enabled=None, default_branch=None, description=None, initialize_with_readme=None, issues_enabled=None, lfs_enabled=None, merge_method=None, merge_requests_enabled=None, name=None, namespace_id=None, only_allow_merge_if_all_discussions_are_resolved=None, only_allow_merge_if_pipeline_succeeds=None, path=None, pipelines_enabled=None, remove_source_branch_after_merge=None, request_access_enabled=None, shared_runners_enabled=None, shared_with_groups=None, snippets_enabled=None, tags=None, visibility_level=None, wiki_enabled=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a Project resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] approvals_before_merge: Number of merge request approvals required for merging. Default is 0.
        :param pulumi.Input[bool] archived: Whether the project is in read-only mode (archived). Repositories can be archived/unarchived by toggling this parameter.
        :param pulumi.Input[bool] container_registry_enabled: Enable container registry for the project.
        :param pulumi.Input[str] default_branch: The default branch for the project.
        :param pulumi.Input[str] description: A description of the project.
        :param pulumi.Input[bool] initialize_with_readme: Create master branch with first commit containing a README.md file.
        :param pulumi.Input[bool] issues_enabled: Enable issue tracking for the project.
        :param pulumi.Input[bool] lfs_enabled: Enable LFS for the project.
        :param pulumi.Input[str] merge_method: Set to `ff` to create fast-forward merges
               Valid values are `merge`, `rebase_merge`, `ff`
               Repositories are created with `merge` by default
        :param pulumi.Input[bool] merge_requests_enabled: Enable merge requests for the project.
        :param pulumi.Input[str] name: The name of the project.
        :param pulumi.Input[float] namespace_id: The namespace (group or user) of the project. Defaults to your user.
               See `Group` for an example.
        :param pulumi.Input[bool] only_allow_merge_if_all_discussions_are_resolved: Set to true if you want allow merges only if all discussions are resolved.
        :param pulumi.Input[bool] only_allow_merge_if_pipeline_succeeds: Set to true if you want allow merges only if a pipeline succeeds.
        :param pulumi.Input[str] path: The path of the repository.
        :param pulumi.Input[bool] pipelines_enabled: Enable pipelines for the project.
        :param pulumi.Input[bool] remove_source_branch_after_merge: Enable `Delete source branch` option by default for all new merge requests.
        :param pulumi.Input[bool] request_access_enabled: Allow users to request member access.
        :param pulumi.Input[bool] shared_runners_enabled: Enable shared runners for this project.
        :param pulumi.Input[list] shared_with_groups: Enable sharing the project with a list of groups (maps).
        :param pulumi.Input[bool] snippets_enabled: Enable snippets for the project.
        :param pulumi.Input[list] tags: Tags (topics) of the project.
        :param pulumi.Input[str] visibility_level: Set to `public` to create a public project.
               Valid values are `private`, `internal`, `public`.
               Repositories are created as private by default.
        :param pulumi.Input[bool] wiki_enabled: Enable wiki for the project.

        The **shared_with_groups** object supports the following:

          * `groupAccessLevel` (`pulumi.Input[str]`) - Group's sharing permissions. See [group members permission][group_members_permissions] for more info.
            Valid values are `guest`, `reporter`, `developer`, `master`.
          * `group_id` (`pulumi.Input[float]`) - Group id of the group you want to share the project with.
          * `groupName` (`pulumi.Input[str]`) - Group's name.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['approvals_before_merge'] = approvals_before_merge
            __props__['archived'] = archived
            __props__['container_registry_enabled'] = container_registry_enabled
            __props__['default_branch'] = default_branch
            __props__['description'] = description
            __props__['initialize_with_readme'] = initialize_with_readme
            __props__['issues_enabled'] = issues_enabled
            __props__['lfs_enabled'] = lfs_enabled
            __props__['merge_method'] = merge_method
            __props__['merge_requests_enabled'] = merge_requests_enabled
            __props__['name'] = name
            __props__['namespace_id'] = namespace_id
            __props__['only_allow_merge_if_all_discussions_are_resolved'] = only_allow_merge_if_all_discussions_are_resolved
            __props__['only_allow_merge_if_pipeline_succeeds'] = only_allow_merge_if_pipeline_succeeds
            __props__['path'] = path
            __props__['pipelines_enabled'] = pipelines_enabled
            __props__['remove_source_branch_after_merge'] = remove_source_branch_after_merge
            __props__['request_access_enabled'] = request_access_enabled
            __props__['shared_runners_enabled'] = shared_runners_enabled
            __props__['shared_with_groups'] = shared_with_groups
            __props__['snippets_enabled'] = snippets_enabled
            __props__['tags'] = tags
            __props__['visibility_level'] = visibility_level
            __props__['wiki_enabled'] = wiki_enabled
            __props__['http_url_to_repo'] = None
            __props__['runners_token'] = None
            __props__['ssh_url_to_repo'] = None
            __props__['web_url'] = None
        super(Project, __self__).__init__(
            'gitlab:index/project:Project',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, approvals_before_merge=None, archived=None, container_registry_enabled=None, default_branch=None, description=None, http_url_to_repo=None, initialize_with_readme=None, issues_enabled=None, lfs_enabled=None, merge_method=None, merge_requests_enabled=None, name=None, namespace_id=None, only_allow_merge_if_all_discussions_are_resolved=None, only_allow_merge_if_pipeline_succeeds=None, path=None, pipelines_enabled=None, remove_source_branch_after_merge=None, request_access_enabled=None, runners_token=None, shared_runners_enabled=None, shared_with_groups=None, snippets_enabled=None, ssh_url_to_repo=None, tags=None, visibility_level=None, web_url=None, wiki_enabled=None):
        """
        Get an existing Project resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[float] approvals_before_merge: Number of merge request approvals required for merging. Default is 0.
        :param pulumi.Input[bool] archived: Whether the project is in read-only mode (archived). Repositories can be archived/unarchived by toggling this parameter.
        :param pulumi.Input[bool] container_registry_enabled: Enable container registry for the project.
        :param pulumi.Input[str] default_branch: The default branch for the project.
        :param pulumi.Input[str] description: A description of the project.
        :param pulumi.Input[str] http_url_to_repo: URL that can be provided to `git clone` to clone the
               repository via HTTP.
        :param pulumi.Input[bool] initialize_with_readme: Create master branch with first commit containing a README.md file.
        :param pulumi.Input[bool] issues_enabled: Enable issue tracking for the project.
        :param pulumi.Input[bool] lfs_enabled: Enable LFS for the project.
        :param pulumi.Input[str] merge_method: Set to `ff` to create fast-forward merges
               Valid values are `merge`, `rebase_merge`, `ff`
               Repositories are created with `merge` by default
        :param pulumi.Input[bool] merge_requests_enabled: Enable merge requests for the project.
        :param pulumi.Input[str] name: The name of the project.
        :param pulumi.Input[float] namespace_id: The namespace (group or user) of the project. Defaults to your user.
               See `Group` for an example.
        :param pulumi.Input[bool] only_allow_merge_if_all_discussions_are_resolved: Set to true if you want allow merges only if all discussions are resolved.
        :param pulumi.Input[bool] only_allow_merge_if_pipeline_succeeds: Set to true if you want allow merges only if a pipeline succeeds.
        :param pulumi.Input[str] path: The path of the repository.
        :param pulumi.Input[bool] pipelines_enabled: Enable pipelines for the project.
        :param pulumi.Input[bool] remove_source_branch_after_merge: Enable `Delete source branch` option by default for all new merge requests.
        :param pulumi.Input[bool] request_access_enabled: Allow users to request member access.
        :param pulumi.Input[str] runners_token: Registration token to use during runner setup.
        :param pulumi.Input[bool] shared_runners_enabled: Enable shared runners for this project.
        :param pulumi.Input[list] shared_with_groups: Enable sharing the project with a list of groups (maps).
        :param pulumi.Input[bool] snippets_enabled: Enable snippets for the project.
        :param pulumi.Input[str] ssh_url_to_repo: URL that can be provided to `git clone` to clone the
               repository via SSH.
        :param pulumi.Input[list] tags: Tags (topics) of the project.
        :param pulumi.Input[str] visibility_level: Set to `public` to create a public project.
               Valid values are `private`, `internal`, `public`.
               Repositories are created as private by default.
        :param pulumi.Input[str] web_url: URL that can be used to find the project in a browser.
        :param pulumi.Input[bool] wiki_enabled: Enable wiki for the project.

        The **shared_with_groups** object supports the following:

          * `groupAccessLevel` (`pulumi.Input[str]`) - Group's sharing permissions. See [group members permission][group_members_permissions] for more info.
            Valid values are `guest`, `reporter`, `developer`, `master`.
          * `group_id` (`pulumi.Input[float]`) - Group id of the group you want to share the project with.
          * `groupName` (`pulumi.Input[str]`) - Group's name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["approvals_before_merge"] = approvals_before_merge
        __props__["archived"] = archived
        __props__["container_registry_enabled"] = container_registry_enabled
        __props__["default_branch"] = default_branch
        __props__["description"] = description
        __props__["http_url_to_repo"] = http_url_to_repo
        __props__["initialize_with_readme"] = initialize_with_readme
        __props__["issues_enabled"] = issues_enabled
        __props__["lfs_enabled"] = lfs_enabled
        __props__["merge_method"] = merge_method
        __props__["merge_requests_enabled"] = merge_requests_enabled
        __props__["name"] = name
        __props__["namespace_id"] = namespace_id
        __props__["only_allow_merge_if_all_discussions_are_resolved"] = only_allow_merge_if_all_discussions_are_resolved
        __props__["only_allow_merge_if_pipeline_succeeds"] = only_allow_merge_if_pipeline_succeeds
        __props__["path"] = path
        __props__["pipelines_enabled"] = pipelines_enabled
        __props__["remove_source_branch_after_merge"] = remove_source_branch_after_merge
        __props__["request_access_enabled"] = request_access_enabled
        __props__["runners_token"] = runners_token
        __props__["shared_runners_enabled"] = shared_runners_enabled
        __props__["shared_with_groups"] = shared_with_groups
        __props__["snippets_enabled"] = snippets_enabled
        __props__["ssh_url_to_repo"] = ssh_url_to_repo
        __props__["tags"] = tags
        __props__["visibility_level"] = visibility_level
        __props__["web_url"] = web_url
        __props__["wiki_enabled"] = wiki_enabled
        return Project(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class User(pulumi.CustomResource):
    can_create_group: pulumi.Output[bool]
    """
    Boolean, defaults to false. Whether to allow the user to create groups.
    """
    email: pulumi.Output[str]
    """
    The e-mail address of the user.
    """
    is_admin: pulumi.Output[bool]
    """
    Boolean, defaults to false.  Whether to enable administrative priviledges
    for the user.
    """
    is_external: pulumi.Output[bool]
    """
    Boolean, defaults to false. Whether a user has access only to some internal or private projects. External users can only access projects to which they are explicitly granted access.
    """
    name: pulumi.Output[str]
    """
    The name of the user.
    """
    password: pulumi.Output[str]
    """
    The password of the user.
    """
    projects_limit: pulumi.Output[float]
    """
    Integer, defaults to 0.  Number of projects user can create.
    """
    reset_password: pulumi.Output[bool]
    """
    Boolean, defaults to false. Send user password reset link.
    """
    skip_confirmation: pulumi.Output[bool]
    """
    Boolean, defaults to true. Whether to skip confirmation.
    """
    username: pulumi.Output[str]
    """
    The username of the user.
    """
    def __init__(__self__, resource_name, opts=None, can_create_group=None, email=None, is_admin=None, is_external=None, name=None, password=None, projects_limit=None, reset_password=None, skip_confirmation=None, username=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a User resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] can_create_group: Boolean, defaults to false. Whether to allow the user to create groups.
        :param pulumi.Input[str] email: The e-mail address of the user.
        :param pulumi.Input[bool] is_admin: Boolean, defaults to false.  Whether to enable administrative priviledges
               for the user.
        :param pulumi.Input[bool] is_external: Boolean, defaults to false. Whether a user has access only to some internal or private projects. External users can only access projects to which they are explicitly granted access.
        :param pulumi.Input[str] name: The name of the user.
        :param pulumi.Input[str] password: The password of the user.
        :param pulumi.Input[float] projects_limit: Integer, defaults to 0.  Number of projects user can create.
        :param pulumi.Input[bool] reset_password: Boolean, defaults to false. Send user password reset link.
        :param pulumi.Input[bool] skip_confirmation: Boolean, defaults to true. Whether to skip confirmation.
        :param pulumi.Input[str] username: The username of the user.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['can_create_group'] = can_create_group
            if email is None:
                raise TypeError("Missing required property 'email'")
            __props__['email'] = email
            __props__['is_admin'] = is_admin
            __props__['is_external'] = is_external
            __props__['name'] = name
            __props__['password'] = password
            __props__['projects_limit'] = projects_limit
            __props__['reset_password'] = reset_password
            __props__['skip_confirmation'] = skip_confirmation
            if username is None:
                raise TypeError("Missing required property 'username'")
            __props__['username'] = username
        super(User, __self__).__init__(
            'gitlab:index/user:User',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, can_create_group=None, email=None, is_admin=None, is_external=None, name=None, password=None, projects_limit=None, reset_password=None, skip_confirmation=None, username=None):
        """
        Get an existing User resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] can_create_group: Boolean, defaults to false. Whether to allow the user to create groups.
        :param pulumi.Input[str] email: The e-mail address of the user.
        :param pulumi.Input[bool] is_admin: Boolean, defaults to false.  Whether to enable administrative priviledges
               for the user.
        :param pulumi.Input[bool] is_external: Boolean, defaults to false. Whether a user has access only to some internal or private projects. External users can only access projects to which they are explicitly granted access.
        :param pulumi.Input[str] name: The name of the user.
        :param pulumi.Input[str] password: The password of the user.
        :param pulumi.Input[float] projects_limit: Integer, defaults to 0.  Number of projects user can create.
        :param pulumi.Input[bool] reset_password: Boolean, defaults to false. Send user password reset link.
        :param pulumi.Input[bool] skip_confirmation: Boolean, defaults to true. Whether to skip confirmation.
        :param pulumi.Input[str] username: The username of the user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["can_create_group"] = can_create_group
        __props__["email"] = email
        __props__["is_admin"] = is_admin
        __props__["is_external"] = is_external
        __props__["name"] = name
        __props__["password"] = password
        __props__["projects_limit"] = projects_limit
        __props__["reset_password"] = reset_password
        __props__["skip_confirmation"] = skip_confirmation
        __props__["username"] = username
        return User(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetProjectResult:
    """
    A collection of values returned by getProject.
    """
    def __init__(__self__, archived=None, default_branch=None, description=None, http_url_to_repo=None, id=None, issues_enabled=None, lfs_enabled=None, merge_requests_enabled=None, name=None, namespace_id=None, path=None, pipelines_enabled=None, remove_source_branch_after_merge=None, request_access_enabled=None, runners_token=None, snippets_enabled=None, ssh_url_to_repo=None, visibility_level=None, web_url=None, wiki_enabled=None):
        if archived and not isinstance(archived, bool):
            raise TypeError("Expected argument 'archived' to be a bool")
        __self__.archived = archived
        """
        Whether the project is in read-only mode (archived).
        """
        if default_branch and not isinstance(default_branch, str):
            raise TypeError("Expected argument 'default_branch' to be a str")
        __self__.default_branch = default_branch
        """
        The default branch for the project.
        """
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        A description of the project.
        """
        if http_url_to_repo and not isinstance(http_url_to_repo, str):
            raise TypeError("Expected argument 'http_url_to_repo' to be a str")
        __self__.http_url_to_repo = http_url_to_repo
        """
        URL that can be provided to `git clone` to clone the
        repository via HTTP.
        """
        if id and not isinstance(id, float):
            raise TypeError("Expected argument 'id' to be a float")
        __self__.id = id
        """
        Integer that uniquely identifies the project within the gitlab install.
        """
        if issues_enabled and not isinstance(issues_enabled, bool):
            raise TypeError("Expected argument 'issues_enabled' to be a bool")
        __self__.issues_enabled = issues_enabled
        """
        Enable issue tracking for the project.
        """
        if lfs_enabled and not isinstance(lfs_enabled, bool):
            raise TypeError("Expected argument 'lfs_enabled' to be a bool")
        __self__.lfs_enabled = lfs_enabled
        """
        Enable LFS for the project.
        """
        if merge_requests_enabled and not isinstance(merge_requests_enabled, bool):
            raise TypeError("Expected argument 'merge_requests_enabled' to be a bool")
        __self__.merge_requests_enabled = merge_requests_enabled
        """
        Enable merge requests for the project.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        if namespace_id and not isinstance(namespace_id, float):
            raise TypeError("Expected argument 'namespace_id' to be a float")
        __self__.namespace_id = namespace_id
        """
        The namespace (group or user) of the project. Defaults to your user.
        See `Group` for an example.
        """
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        __self__.path = path
        """
        The path of the repository.
        """
        if pipelines_enabled and not isinstance(pipelines_enabled, bool):
            raise TypeError("Expected argument 'pipelines_enabled' to be a bool")
        __self__.pipelines_enabled = pipelines_enabled
        """
        Enable pipelines for the project.
        """
        if remove_source_branch_after_merge and not isinstance(remove_source_branch_after_merge, bool):
            raise TypeError("Expected argument 'remove_source_branch_after_merge' to be a bool")
        __self__.remove_source_branch_after_merge = remove_source_branch_after_merge
        """
        Enable `Delete source branch` option by default for all new merge requests
        """
        if request_access_enabled and not isinstance(request_access_enabled, bool):
            raise TypeError("Expected argument 'request_access_enabled' to be a bool")
        __self__.request_access_enabled = request_access_enabled
        """
        Allow users to request member access.
        """
        if runners_token and not isinstance(runners_token, str):
            raise TypeError("Expected argument 'runners_token' to be a str")
        __self__.runners_token = runners_token
        """
        Registration token to use during runner setup.
        """
        if snippets_enabled and not isinstance(snippets_enabled, bool):
            raise TypeError("Expected argument 'snippets_enabled' to be a bool")
        __self__.snippets_enabled = snippets_enabled
        """
        Enable snippets for the project.
        """
        if ssh_url_to_repo and not isinstance(ssh_url_to_repo, str):
            raise TypeError("Expected argument 'ssh_url_to_repo' to be a str")
        __self__.ssh_url_to_repo = ssh_url_to_repo
        """
        URL that can be provided to `git clone` to clone the
        repository via SSH.
        """
        if visibility_level and not isinstance(visibility_level, str):
            raise TypeError("Expected argument 'visibility_level' to be a str")
        __self__.visibility_level = visibility_level
        """
        Repositories are created as private by default.
        """
        if web_url and not isinstance(web_url, str):
            raise TypeError("Expected argument 'web_url' to be a str")
        __self__.web_url = web_url
        """
        URL that can be used to find the project in a browser.
        """
        if wiki_enabled and not isinstance(wiki_enabled, bool):
            raise TypeError("Expected argument 'wiki_enabled' to be a bool")
        __self__.wiki_enabled = wiki_enabled
        """
        Enable wiki for the project.
        """
class AwaitableGetProjectResult(GetProjectResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectResult(
            archived=self.archived,
            default_branch=self.default_branch,
            description=self.description,
            http_url_to_repo=self.http_url_to_repo,
            id=self.id,
            issues_enabled=self.issues_enabled,
            lfs_enabled=self.lfs_enabled,
            merge_requests_enabled=self.merge_requests_enabled,
            name=self.name,
            namespace_id=self.namespace_id,
            path=self.path,
            pipelines_enabled=self.pipelines_enabled,
            remove_source_branch_after_merge=self.remove_source_branch_after_merge,
            request_access_enabled=self.request_access_enabled,
            runners_token=self.runners_token,
            snippets_enabled=self.snippets_enabled,
            ssh_url_to_repo=self.ssh_url_to_repo,
            visibility_level=self.visibility_level,
            web_url=self.web_url,
            wiki_enabled=self.wiki_enabled)

def get_project(archived=None,default_branch=None,description=None,http_url_to_repo=None,id=None,issues_enabled=None,lfs_enabled=None,merge_requests_enabled=None,name=None,namespace_id=None,path=None,pipelines_enabled=None,remove_source_branch_after_merge=None,request_access_enabled=None,runners_token=None,snippets_enabled=None,ssh_url_to_repo=None,visibility_level=None,web_url=None,wiki_enabled=None,opts=None):
    """
    Provides details about a specific project in the gitlab provider. The results include the name of the project, path, description, default branch, etc.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_project(id=30)
    ```


    :param bool archived: Whether the project is in read-only mode (archived).
    :param str default_branch: The default branch for the project.
    :param str description: A description of the project.
    :param str http_url_to_repo: URL that can be provided to `git clone` to clone the
           repository via HTTP.
    :param float id: The integer that uniquely identifies the project within the gitlab install.
    :param bool issues_enabled: Enable issue tracking for the project.
    :param bool lfs_enabled: Enable LFS for the project.
    :param bool merge_requests_enabled: Enable merge requests for the project.
    :param float namespace_id: The namespace (group or user) of the project. Defaults to your user.
           See `Group` for an example.
    :param str path: The path of the repository.
    :param bool pipelines_enabled: Enable pipelines for the project.
    :param bool remove_source_branch_after_merge: Enable `Delete source branch` option by default for all new merge requests
    :param bool request_access_enabled: Allow users to request member access.
    :param str runners_token: Registration token to use during runner setup.
    :param bool snippets_enabled: Enable snippets for the project.
    :param str ssh_url_to_repo: URL that can be provided to `git clone` to clone the
           repository via SSH.
    :param str visibility_level: Repositories are created as private by default.
    :param str web_url: URL that can be used to find the project in a browser.
    :param bool wiki_enabled: Enable wiki for the project.
    """
    __args__ = dict()


    __args__['archived'] = archived
    __args__['defaultBranch'] = default_branch
    __args__['description'] = description
    __args__['httpUrlToRepo'] = http_url_to_repo
    __args__['id'] = id
    __args__['issuesEnabled'] = issues_enabled
    __args__['lfsEnabled'] = lfs_enabled
    __args__['mergeRequestsEnabled'] = merge_requests_enabled
    __args__['name'] = name
    __args__['namespaceId'] = namespace_id
    __args__['path'] = path
    __args__['pipelinesEnabled'] = pipelines_enabled
    __args__['removeSourceBranchAfterMerge'] = remove_source_branch_after_merge
    __args__['requestAccessEnabled'] = request_access_enabled
    __args__['runnersToken'] = runners_token
    __args__['snippetsEnabled'] = snippets_enabled
    __args__['sshUrlToRepo'] = ssh_url_to_repo
    __args__['visibilityLevel'] = visibility_level
    __args__['webUrl'] = web_url
    __args__['wikiEnabled'] = wiki_enabled
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProject:getProject', __args__, opts=opts).value

    return AwaitableGetProjectResult(
        archived=__ret__.get('archived'),
        default_branch=__ret__.get('defaultBranch'),
        description=__ret__.get('description'),
        http_url_to_repo=__ret__.get('httpUrlToRepo'),
        id=__ret__.get('id'),
        issues_enabled=__ret__.get('issuesEnabled'),
        lfs_enabled=__ret__.get('lfsEnabled'),
        merge_requests_enabled=__ret__.get('mergeRequestsEnabled'),
        name=__ret__.get('name'),
        namespace_id=__ret__.get('namespaceId'),
        path=__ret__.get('path'),
        pipelines_enabled=__ret__.get('pipelinesEnabled'),
        remove_source_branch_after_merge=__ret__.get('removeSourceBranchAfterMerge'),
        request_access_enabled=__ret__.get('requestAccessEnabled'),
        runners_token=__ret__.get('runnersToken'),
        snippets_enabled=__ret__.get('snippetsEnabled'),
        ssh_url_to_repo=__ret__.get('sshUrlToRepo'),
        visibility_level=__ret__.get('visibilityLevel'),
        web_url=__ret__.get('webUrl'),
        wiki_enabled=__ret__.get('wikiEnabled'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetUsersResult:
    """
    A collection of values returned by getUsers.
    """
    def __init__(__self__, active=None, blocked=None, created_after=None, created_before=None, extern_provider=None, extern_uid=None, id=None, order_by=None, search=None, sort=None, users=None):
        if active and not isinstance(active, bool):
            raise TypeError("Expected argument 'active' to be a bool")
        __self__.active = active
        if blocked and not isinstance(blocked, bool):
            raise TypeError("Expected argument 'blocked' to be a bool")
        __self__.blocked = blocked
        if created_after and not isinstance(created_after, str):
            raise TypeError("Expected argument 'created_after' to be a str")
        __self__.created_after = created_after
        if created_before and not isinstance(created_before, str):
            raise TypeError("Expected argument 'created_before' to be a str")
        __self__.created_before = created_before
        if extern_provider and not isinstance(extern_provider, str):
            raise TypeError("Expected argument 'extern_provider' to be a str")
        __self__.extern_provider = extern_provider
        if extern_uid and not isinstance(extern_uid, str):
            raise TypeError("Expected argument 'extern_uid' to be a str")
        __self__.extern_uid = extern_uid
        """
        The external UID of the user.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        __self__.order_by = order_by
        if search and not isinstance(search, str):
            raise TypeError("Expected argument 'search' to be a str")
        __self__.search = search
        if sort and not isinstance(sort, str):
            raise TypeError("Expected argument 'sort' to be a str")
        __self__.sort = sort
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        __self__.users = users
        """
        The list of users.
        """
class AwaitableGetUsersResult(GetUsersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUsersResult(
            active=self.active,
            blocked=self.blocked,
            created_after=self.created_after,
            created_before=self.created_before,
            extern_provider=self.extern_provider,
            extern_uid=self.extern_uid,
            id=self.id,
            order_by=self.order_by,
            search=self.search,
            sort=self.sort,
            users=self.users)

def get_users(active=None,blocked=None,created_after=None,created_before=None,extern_provider=None,extern_uid=None,order_by=None,search=None,sort=None,opts=None):
    """
    Provides details about a list of users in the gitlab provider. The results include id, username, email, name and more about the requested users. Users can also be sorted and filtered using several options.

    **NOTE**: Some of the available options require administrator privileges. Please visit [Gitlab API documentation][users_for_admins] for more information.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_users(created_before="2019-01-01",
        order_by="name",
        sort="desc")
    ```


    :param bool active: Filter users that are active.
    :param bool blocked: Filter users that are blocked.
    :param str created_after: Search for users created after a specific date. (Requires administrator privileges)
    :param str created_before: Search for users created before a specific date. (Requires administrator privileges)
    :param str extern_provider: Lookup users by external provider. (Requires administrator privileges)
    :param str extern_uid: Lookup users by external UID. (Requires administrator privileges)
    :param str order_by: Order the users' list by `id`, `name`, `username`, `created_at` or `updated_at`. (Requires administrator privileges)
    :param str search: Search users by username, name or email.
    :param str sort: Sort users' list in asc or desc order. (Requires administrator privileges)
    """
    __args__ = dict()


    __args__['active'] = active
    __args__['blocked'] = blocked
    __args__['createdAfter'] = created_after
    __args__['createdBefore'] = created_before
    __args__['externProvider'] = extern_provider
    __args__['externUid'] = extern_uid
    __args__['orderBy'] = order_by
    __args__['search'] = search
    __args__['sort'] = sort
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('gitlab:index/getUsers:getUsers', __args__, opts=opts).value

    return AwaitableGetUsersResult(
        active=__ret__.get('active'),
        blocked=__ret__.get('blocked'),
        created_after=__ret__.get('createdAfter'),
        created_before=__ret__.get('createdBefore'),
        extern_provider=__ret__.get('externProvider'),
        extern_uid=__ret__.get('externUid'),
        id=__ret__.get('id'),
        order_by=__ret__.get('orderBy'),
        search=__ret__.get('search'),
        sort=__ret__.get('sort'),
        users=__ret__.get('users'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

# Export this package's modules as members:
from .branch_protection import *
from .deploy_key import *
from .deploy_key_enable import *
from .deploy_token import *
from .get_group import *
from .get_project import *
from .get_projects import *
from .get_user import *
from .get_users import *
from .group import *
from .group_cluster import *
from .group_label import *
from .group_ldap_link import *
from .group_membership import *
from .group_variable import *
from .label import *
from .pipeline_schedule import *
from .pipeline_schedule_variable import *
from .pipeline_trigger import *
from .project import *
from .project_cluster import *
from .project_hook import *
from .project_membership import *
from .project_push_rules import *
from .project_share_group import *
from .project_variable import *
from .provider import *
from .service_github import *
from .service_jira import *
from .service_slack import *
from .tag_protection import *
from .user import *



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetUserResult:
    """
    A collection of values returned by getUser.
    """
    def __init__(__self__, avatar_url=None, bio=None, can_create_group=None, can_create_project=None, color_scheme_id=None, created_at=None, current_sign_in_at=None, email=None, extern_uid=None, external=None, id=None, is_admin=None, last_sign_in_at=None, linkedin=None, location=None, name=None, organization=None, projects_limit=None, skype=None, state=None, theme_id=None, twitter=None, two_factor_enabled=None, user_id=None, user_provider=None, username=None, website_url=None):
        if avatar_url and not isinstance(avatar_url, str):
            raise TypeError("Expected argument 'avatar_url' to be a str")
        __self__.avatar_url = avatar_url
        """
        The avatar URL of the user.
        """
        if bio and not isinstance(bio, str):
            raise TypeError("Expected argument 'bio' to be a str")
        __self__.bio = bio
        """
        The bio of the user.
        """
        if can_create_group and not isinstance(can_create_group, bool):
            raise TypeError("Expected argument 'can_create_group' to be a bool")
        __self__.can_create_group = can_create_group
        """
        Whether the user can create groups.
        """
        if can_create_project and not isinstance(can_create_project, bool):
            raise TypeError("Expected argument 'can_create_project' to be a bool")
        __self__.can_create_project = can_create_project
        """
        Whether the user can create projects.
        """
        if color_scheme_id and not isinstance(color_scheme_id, float):
            raise TypeError("Expected argument 'color_scheme_id' to be a float")
        __self__.color_scheme_id = color_scheme_id
        """
        User's color scheme ID.
        """
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        __self__.created_at = created_at
        """
        Date the user was created at.
        """
        if current_sign_in_at and not isinstance(current_sign_in_at, str):
            raise TypeError("Expected argument 'current_sign_in_at' to be a str")
        __self__.current_sign_in_at = current_sign_in_at
        """
        Current user's sign-in date.
        """
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        __self__.email = email
        """
        The e-mail address of the user.
        """
        if extern_uid and not isinstance(extern_uid, str):
            raise TypeError("Expected argument 'extern_uid' to be a str")
        __self__.extern_uid = extern_uid
        """
        The external UID of the user.
        """
        if external and not isinstance(external, bool):
            raise TypeError("Expected argument 'external' to be a bool")
        __self__.external = external
        """
        Whether the user is external.
        """
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if is_admin and not isinstance(is_admin, bool):
            raise TypeError("Expected argument 'is_admin' to be a bool")
        __self__.is_admin = is_admin
        """
        Whether the user is an admin.
        """
        if last_sign_in_at and not isinstance(last_sign_in_at, str):
            raise TypeError("Expected argument 'last_sign_in_at' to be a str")
        __self__.last_sign_in_at = last_sign_in_at
        """
        Last user's sign-in date.
        """
        if linkedin and not isinstance(linkedin, str):
            raise TypeError("Expected argument 'linkedin' to be a str")
        __self__.linkedin = linkedin
        """
        Linkedin profile of the user.
        """
        if location and not isinstance(location, str):
            raise TypeError("Expected argument 'location' to be a str")
        __self__.location = location
        """
        The location of the user.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        """
        The name of the user.
        """
        if organization and not isinstance(organization, str):
            raise TypeError("Expected argument 'organization' to be a str")
        __self__.organization = organization
        """
        The organization of the user.
        """
        if projects_limit and not isinstance(projects_limit, float):
            raise TypeError("Expected argument 'projects_limit' to be a float")
        __self__.projects_limit = projects_limit
        """
        Number of projects the user can create.
        """
        if skype and not isinstance(skype, str):
            raise TypeError("Expected argument 'skype' to be a str")
        __self__.skype = skype
        """
        Skype username of the user.
        """
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        __self__.state = state
        """
        Whether the user is active or blocked.
        """
        if theme_id and not isinstance(theme_id, float):
            raise TypeError("Expected argument 'theme_id' to be a float")
        __self__.theme_id = theme_id
        """
        User's theme ID.
        """
        if twitter and not isinstance(twitter, str):
            raise TypeError("Expected argument 'twitter' to be a str")
        __self__.twitter = twitter
        """
        Twitter username of the user.
        """
        if two_factor_enabled and not isinstance(two_factor_enabled, bool):
            raise TypeError("Expected argument 'two_factor_enabled' to be a bool")
        __self__.two_factor_enabled = two_factor_enabled
        """
        Whether user's two factor auth is enabled.
        """
        if user_id and not isinstance(user_id, float):
            raise TypeError("Expected argument 'user_id' to be a float")
        __self__.user_id = user_id
        if user_provider and not isinstance(user_provider, str):
            raise TypeError("Expected argument 'user_provider' to be a str")
        __self__.user_provider = user_provider
        """
        The UID provider of the user.
        """
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        __self__.username = username
        """
        The username of the user.
        """
        if website_url and not isinstance(website_url, str):
            raise TypeError("Expected argument 'website_url' to be a str")
        __self__.website_url = website_url
        """
        User's website URL.
        """
class AwaitableGetUserResult(GetUserResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetUserResult(
            avatar_url=self.avatar_url,
            bio=self.bio,
            can_create_group=self.can_create_group,
            can_create_project=self.can_create_project,
            color_scheme_id=self.color_scheme_id,
            created_at=self.created_at,
            current_sign_in_at=self.current_sign_in_at,
            email=self.email,
            extern_uid=self.extern_uid,
            external=self.external,
            id=self.id,
            is_admin=self.is_admin,
            last_sign_in_at=self.last_sign_in_at,
            linkedin=self.linkedin,
            location=self.location,
            name=self.name,
            organization=self.organization,
            projects_limit=self.projects_limit,
            skype=self.skype,
            state=self.state,
            theme_id=self.theme_id,
            twitter=self.twitter,
            two_factor_enabled=self.two_factor_enabled,
            user_id=self.user_id,
            user_provider=self.user_provider,
            username=self.username,
            website_url=self.website_url)

def get_user(email=None,user_id=None,username=None,opts=None):
    """
    Provides details about a specific user in the gitlab provider. Especially the ability to lookup the id for linking to other resources.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example = gitlab.get_user(username="myuser")
    ```


    :param str email: The e-mail address of the user. (Requires administrator privileges)
    :param float user_id: The ID of the user.
    :param str username: The username of the user.
    """
    __args__ = dict()


    __args__['email'] = email
    __args__['userId'] = user_id
    __args__['username'] = username
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('gitlab:index/getUser:getUser', __args__, opts=opts).value

    return AwaitableGetUserResult(
        avatar_url=__ret__.get('avatarUrl'),
        bio=__ret__.get('bio'),
        can_create_group=__ret__.get('canCreateGroup'),
        can_create_project=__ret__.get('canCreateProject'),
        color_scheme_id=__ret__.get('colorSchemeId'),
        created_at=__ret__.get('createdAt'),
        current_sign_in_at=__ret__.get('currentSignInAt'),
        email=__ret__.get('email'),
        extern_uid=__ret__.get('externUid'),
        external=__ret__.get('external'),
        id=__ret__.get('id'),
        is_admin=__ret__.get('isAdmin'),
        last_sign_in_at=__ret__.get('lastSignInAt'),
        linkedin=__ret__.get('linkedin'),
        location=__ret__.get('location'),
        name=__ret__.get('name'),
        organization=__ret__.get('organization'),
        projects_limit=__ret__.get('projectsLimit'),
        skype=__ret__.get('skype'),
        state=__ret__.get('state'),
        theme_id=__ret__.get('themeId'),
        twitter=__ret__.get('twitter'),
        two_factor_enabled=__ret__.get('twoFactorEnabled'),
        user_id=__ret__.get('userId'),
        user_provider=__ret__.get('userProvider'),
        username=__ret__.get('username'),
        website_url=__ret__.get('websiteUrl'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class PipelineSchedule(pulumi.CustomResource):
    active: pulumi.Output[bool]
    """
    The activation of pipeline schedule. If false is set, the pipeline schedule will deactivated initially.
    """
    cron: pulumi.Output[str]
    """
    The cron (e.g. `0 1 * * *`).
    """
    cron_timezone: pulumi.Output[str]
    """
    The timezone.
    """
    description: pulumi.Output[str]
    """
    The description of the pipeline schedule.
    """
    project: pulumi.Output[str]
    """
    The name or id of the project to add the schedule to.
    """
    ref: pulumi.Output[str]
    """
    The branch/tag name to be triggered.
    """
    def __init__(__self__, resource_name, opts=None, active=None, cron=None, cron_timezone=None, description=None, project=None, ref=None, __props__=None, __name__=None, __opts__=None):
        """
        This resource allows you to create and manage pipeline schedules.
        For further information on clusters, consult the [gitlab
        documentation](https://docs.gitlab.com/ce/user/project/pipelines/schedules.html).

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.PipelineSchedule("example",
            cron="0 1 * * *",
            description="Used to schedule builds",
            project="12345",
            ref="master")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: The activation of pipeline schedule. If false is set, the pipeline schedule will deactivated initially.
        :param pulumi.Input[str] cron: The cron (e.g. `0 1 * * *`).
        :param pulumi.Input[str] cron_timezone: The timezone.
        :param pulumi.Input[str] description: The description of the pipeline schedule.
        :param pulumi.Input[str] project: The name or id of the project to add the schedule to.
        :param pulumi.Input[str] ref: The branch/tag name to be triggered.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['active'] = active
            if cron is None:
                raise TypeError("Missing required property 'cron'")
            __props__['cron'] = cron
            __props__['cron_timezone'] = cron_timezone
            if description is None:
                raise TypeError("Missing required property 'description'")
            __props__['description'] = description
            if project is None:
                raise TypeError("Missing required property 'project'")
            __props__['project'] = project
            if ref is None:
                raise TypeError("Missing required property 'ref'")
            __props__['ref'] = ref
        super(PipelineSchedule, __self__).__init__(
            'gitlab:index/pipelineSchedule:PipelineSchedule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, active=None, cron=None, cron_timezone=None, description=None, project=None, ref=None):
        """
        Get an existing PipelineSchedule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] active: The activation of pipeline schedule. If false is set, the pipeline schedule will deactivated initially.
        :param pulumi.Input[str] cron: The cron (e.g. `0 1 * * *`).
        :param pulumi.Input[str] cron_timezone: The timezone.
        :param pulumi.Input[str] description: The description of the pipeline schedule.
        :param pulumi.Input[str] project: The name or id of the project to add the schedule to.
        :param pulumi.Input[str] ref: The branch/tag name to be triggered.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["active"] = active
        __props__["cron"] = cron
        __props__["cron_timezone"] = cron_timezone
        __props__["description"] = description
        __props__["project"] = project
        __props__["ref"] = ref
        return PipelineSchedule(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetGroupResult:
    """
    A collection of values returned by getGroup.
    """
    def __init__(__self__, description=None, full_name=None, full_path=None, group_id=None, id=None, lfs_enabled=None, name=None, parent_id=None, path=None, request_access_enabled=None, runners_token=None, visibility_level=None, web_url=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        __self__.description = description
        """
        The description of the group.
        """
        if full_name and not isinstance(full_name, str):
            raise TypeError("Expected argument 'full_name' to be a str")
        __self__.full_name = full_name
        """
        The full name of the group.
        """
        if full_path and not isinstance(full_path, str):
            raise TypeError("Expected argument 'full_path' to be a str")
        __self__.full_path = full_path
        """
        The full path of the group.
        """
        if group_id and not isinstance(group_id, float):
            raise TypeError("Expected argument 'group_id' to be a float")
        __self__.group_id = group_id
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if lfs_enabled and not isinstance(lfs_enabled, bool):
            raise TypeError("Expected argument 'lfs_enabled' to be a bool")
        __self__.lfs_enabled = lfs_enabled
        """
        Boolean, is LFS enabled for projects in this group.
        """
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        __self__.name = name
        """
        The name of this group.
        """
        if parent_id and not isinstance(parent_id, float):
            raise TypeError("Expected argument 'parent_id' to be a float")
        __self__.parent_id = parent_id
        """
        Integer, ID of the parent group.
        """
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        __self__.path = path
        """
        The path of the group.
        """
        if request_access_enabled and not isinstance(request_access_enabled, bool):
            raise TypeError("Expected argument 'request_access_enabled' to be a bool")
        __self__.request_access_enabled = request_access_enabled
        """
        Boolean, is request for access enabled to the group.
        """
        if runners_token and not isinstance(runners_token, str):
            raise TypeError("Expected argument 'runners_token' to be a str")
        __self__.runners_token = runners_token
        """
        The group level registration token to use during runner setup.
        """
        if visibility_level and not isinstance(visibility_level, str):
            raise TypeError("Expected argument 'visibility_level' to be a str")
        __self__.visibility_level = visibility_level
        """
        Visibility level of the group. Possible values are `private`, `internal`, `public`.
        """
        if web_url and not isinstance(web_url, str):
            raise TypeError("Expected argument 'web_url' to be a str")
        __self__.web_url = web_url
        """
        Web URL of the group.
        """
class AwaitableGetGroupResult(GetGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGroupResult(
            description=self.description,
            full_name=self.full_name,
            full_path=self.full_path,
            group_id=self.group_id,
            id=self.id,
            lfs_enabled=self.lfs_enabled,
            name=self.name,
            parent_id=self.parent_id,
            path=self.path,
            request_access_enabled=self.request_access_enabled,
            runners_token=self.runners_token,
            visibility_level=self.visibility_level,
            web_url=self.web_url)

def get_group(full_path=None,group_id=None,opts=None):
    """
    Provides details about a specific group in the gitlab provider.

    ## Example Usage

    **By group's ID**

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    foo = gitlab.get_group(group_id=123)
    ```

    **By group's full path**

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    foo = gitlab.get_group(full_path="foo/bar")
    ```


    :param str full_path: The full path of the group.
    :param float group_id: The ID of the group.
    """
    __args__ = dict()


    __args__['fullPath'] = full_path
    __args__['groupId'] = group_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('gitlab:index/getGroup:getGroup', __args__, opts=opts).value

    return AwaitableGetGroupResult(
        description=__ret__.get('description'),
        full_name=__ret__.get('fullName'),
        full_path=__ret__.get('fullPath'),
        group_id=__ret__.get('groupId'),
        id=__ret__.get('id'),
        lfs_enabled=__ret__.get('lfsEnabled'),
        name=__ret__.get('name'),
        parent_id=__ret__.get('parentId'),
        path=__ret__.get('path'),
        request_access_enabled=__ret__.get('requestAccessEnabled'),
        runners_token=__ret__.get('runnersToken'),
        visibility_level=__ret__.get('visibilityLevel'),
        web_url=__ret__.get('webUrl'))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class Group(pulumi.CustomResource):
    description: pulumi.Output[str]
    """
    The description of the group.
    """
    full_name: pulumi.Output[str]
    """
    The full name of the group.
    """
    full_path: pulumi.Output[str]
    """
    The full path of the group.
    """
    lfs_enabled: pulumi.Output[bool]
    """
    Boolean, defaults to true.  Whether to enable LFS
    support for projects in this group.
    """
    name: pulumi.Output[str]
    """
    The name of this group.
    """
    parent_id: pulumi.Output[float]
    """
    Integer, id of the parent group (creates a nested group).
    """
    path: pulumi.Output[str]
    """
    The path of the group.
    """
    request_access_enabled: pulumi.Output[bool]
    """
    Boolean, defaults to false.  Whether to
    enable users to request access to the group.
    """
    runners_token: pulumi.Output[str]
    """
    The group level registration token to use during runner setup.
    """
    visibility_level: pulumi.Output[str]
    """
    Set to `public` to create a public group.
    Valid values are `private`, `internal`, `public`.
    Groups are created as private by default.
    """
    web_url: pulumi.Output[str]
    """
    Web URL of the group.
    """
    def __init__(__self__, resource_name, opts=None, description=None, lfs_enabled=None, name=None, parent_id=None, path=None, request_access_enabled=None, visibility_level=None, __props__=None, __name__=None, __opts__=None):
        """
        Create a Group resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the group.
        :param pulumi.Input[bool] lfs_enabled: Boolean, defaults to true.  Whether to enable LFS
               support for projects in this group.
        :param pulumi.Input[str] name: The name of this group.
        :param pulumi.Input[float] parent_id: Integer, id of the parent group (creates a nested group).
        :param pulumi.Input[str] path: The path of the group.
        :param pulumi.Input[bool] request_access_enabled: Boolean, defaults to false.  Whether to
               enable users to request access to the group.
        :param pulumi.Input[str] visibility_level: Set to `public` to create a public group.
               Valid values are `private`, `internal`, `public`.
               Groups are created as private by default.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            __props__['description'] = description
            __props__['lfs_enabled'] = lfs_enabled
            __props__['name'] = name
            __props__['parent_id'] = parent_id
            if path is None:
                raise TypeError("Missing required property 'path'")
            __props__['path'] = path
            __props__['request_access_enabled'] = request_access_enabled
            __props__['visibility_level'] = visibility_level
            __props__['full_name'] = None
            __props__['full_path'] = None
            __props__['runners_token'] = None
            __props__['web_url'] = None
        super(Group, __self__).__init__(
            'gitlab:index/group:Group',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, description=None, full_name=None, full_path=None, lfs_enabled=None, name=None, parent_id=None, path=None, request_access_enabled=None, runners_token=None, visibility_level=None, web_url=None):
        """
        Get an existing Group resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the group.
        :param pulumi.Input[str] full_name: The full name of the group.
        :param pulumi.Input[str] full_path: The full path of the group.
        :param pulumi.Input[bool] lfs_enabled: Boolean, defaults to true.  Whether to enable LFS
               support for projects in this group.
        :param pulumi.Input[str] name: The name of this group.
        :param pulumi.Input[float] parent_id: Integer, id of the parent group (creates a nested group).
        :param pulumi.Input[str] path: The path of the group.
        :param pulumi.Input[bool] request_access_enabled: Boolean, defaults to false.  Whether to
               enable users to request access to the group.
        :param pulumi.Input[str] runners_token: The group level registration token to use during runner setup.
        :param pulumi.Input[str] visibility_level: Set to `public` to create a public group.
               Valid values are `private`, `internal`, `public`.
               Groups are created as private by default.
        :param pulumi.Input[str] web_url: Web URL of the group.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["description"] = description
        __props__["full_name"] = full_name
        __props__["full_path"] = full_path
        __props__["lfs_enabled"] = lfs_enabled
        __props__["name"] = name
        __props__["parent_id"] = parent_id
        __props__["path"] = path
        __props__["request_access_enabled"] = request_access_enabled
        __props__["runners_token"] = runners_token
        __props__["visibility_level"] = visibility_level
        __props__["web_url"] = web_url
        return Group(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables


class GroupMembership(pulumi.CustomResource):
    access_level: pulumi.Output[str]
    """
    Acceptable values are: guest, reporter, developer, maintainer, owner.
    """
    expires_at: pulumi.Output[str]
    """
    Expiration date for the group membership. Format: `YYYY-MM-DD`
    """
    group_id: pulumi.Output[str]
    """
    The id of the group.
    """
    user_id: pulumi.Output[float]
    """
    The id of the user.
    """
    def __init__(__self__, resource_name, opts=None, access_level=None, expires_at=None, group_id=None, user_id=None, __props__=None, __name__=None, __opts__=None):
        """
        This resource allows you to add a user to an existing group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        test = gitlab.GroupMembership("test",
            access_level="guest",
            expires_at="2020-12-31",
            group_id="12345",
            user_id=1337)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_level: Acceptable values are: guest, reporter, developer, maintainer, owner.
        :param pulumi.Input[str] expires_at: Expiration date for the group membership. Format: `YYYY-MM-DD`
        :param pulumi.Input[str] group_id: The id of the group.
        :param pulumi.Input[float] user_id: The id of the user.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if access_level is None:
                raise TypeError("Missing required property 'access_level'")
            __props__['access_level'] = access_level
            __props__['expires_at'] = expires_at
            if group_id is None:
                raise TypeError("Missing required property 'group_id'")
            __props__['group_id'] = group_id
            if user_id is None:
                raise TypeError("Missing required property 'user_id'")
            __props__['user_id'] = user_id
        super(GroupMembership, __self__).__init__(
            'gitlab:index/groupMembership:GroupMembership',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, access_level=None, expires_at=None, group_id=None, user_id=None):
        """
        Get an existing GroupMembership resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] access_level: Acceptable values are: guest, reporter, developer, maintainer, owner.
        :param pulumi.Input[str] expires_at: Expiration date for the group membership. Format: `YYYY-MM-DD`
        :param pulumi.Input[str] group_id: The id of the group.
        :param pulumi.Input[float] user_id: The id of the user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["access_level"] = access_level
        __props__["expires_at"] = expires_at
        __props__["group_id"] = group_id
        __props__["user_id"] = user_id
        return GroupMembership(resource_name, opts=opts, __props__=__props__)

    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class GetProjectsResult:
    """
    A collection of values returned by getProjects.
    """
    def __init__(__self__, archived=None, group_id=None, id=None, include_subgroups=None, max_queryable_pages=None, membership=None, min_access_level=None, order_by=None, owned=None, page=None, per_page=None, projects=None, search=None, simple=None, sort=None, starred=None, statistics=None, visibility=None, with_custom_attributes=None, with_issues_enabled=None, with_merge_requests_enabled=None, with_programming_language=None, with_shared=None):
        if archived and not isinstance(archived, bool):
            raise TypeError("Expected argument 'archived' to be a bool")
        __self__.archived = archived
        if group_id and not isinstance(group_id, float):
            raise TypeError("Expected argument 'group_id' to be a float")
        __self__.group_id = group_id
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        __self__.id = id
        """
        The provider-assigned unique ID for this managed resource.
        """
        if include_subgroups and not isinstance(include_subgroups, bool):
            raise TypeError("Expected argument 'include_subgroups' to be a bool")
        __self__.include_subgroups = include_subgroups
        if max_queryable_pages and not isinstance(max_queryable_pages, float):
            raise TypeError("Expected argument 'max_queryable_pages' to be a float")
        __self__.max_queryable_pages = max_queryable_pages
        if membership and not isinstance(membership, bool):
            raise TypeError("Expected argument 'membership' to be a bool")
        __self__.membership = membership
        if min_access_level and not isinstance(min_access_level, float):
            raise TypeError("Expected argument 'min_access_level' to be a float")
        __self__.min_access_level = min_access_level
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        __self__.order_by = order_by
        if owned and not isinstance(owned, bool):
            raise TypeError("Expected argument 'owned' to be a bool")
        __self__.owned = owned
        if page and not isinstance(page, float):
            raise TypeError("Expected argument 'page' to be a float")
        __self__.page = page
        if per_page and not isinstance(per_page, float):
            raise TypeError("Expected argument 'per_page' to be a float")
        __self__.per_page = per_page
        if projects and not isinstance(projects, list):
            raise TypeError("Expected argument 'projects' to be a list")
        __self__.projects = projects
        """
        A list containing the projects matching the supplied arguments
        """
        if search and not isinstance(search, str):
            raise TypeError("Expected argument 'search' to be a str")
        __self__.search = search
        if simple and not isinstance(simple, bool):
            raise TypeError("Expected argument 'simple' to be a bool")
        __self__.simple = simple
        if sort and not isinstance(sort, str):
            raise TypeError("Expected argument 'sort' to be a str")
        __self__.sort = sort
        if starred and not isinstance(starred, bool):
            raise TypeError("Expected argument 'starred' to be a bool")
        __self__.starred = starred
        if statistics and not isinstance(statistics, bool):
            raise TypeError("Expected argument 'statistics' to be a bool")
        __self__.statistics = statistics
        if visibility and not isinstance(visibility, str):
            raise TypeError("Expected argument 'visibility' to be a str")
        __self__.visibility = visibility
        """
        The visibility of the project.
        """
        if with_custom_attributes and not isinstance(with_custom_attributes, bool):
            raise TypeError("Expected argument 'with_custom_attributes' to be a bool")
        __self__.with_custom_attributes = with_custom_attributes
        if with_issues_enabled and not isinstance(with_issues_enabled, bool):
            raise TypeError("Expected argument 'with_issues_enabled' to be a bool")
        __self__.with_issues_enabled = with_issues_enabled
        if with_merge_requests_enabled and not isinstance(with_merge_requests_enabled, bool):
            raise TypeError("Expected argument 'with_merge_requests_enabled' to be a bool")
        __self__.with_merge_requests_enabled = with_merge_requests_enabled
        if with_programming_language and not isinstance(with_programming_language, str):
            raise TypeError("Expected argument 'with_programming_language' to be a str")
        __self__.with_programming_language = with_programming_language
        if with_shared and not isinstance(with_shared, bool):
            raise TypeError("Expected argument 'with_shared' to be a bool")
        __self__.with_shared = with_shared
class AwaitableGetProjectsResult(GetProjectsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectsResult(
            archived=self.archived,
            group_id=self.group_id,
            id=self.id,
            include_subgroups=self.include_subgroups,
            max_queryable_pages=self.max_queryable_pages,
            membership=self.membership,
            min_access_level=self.min_access_level,
            order_by=self.order_by,
            owned=self.owned,
            page=self.page,
            per_page=self.per_page,
            projects=self.projects,
            search=self.search,
            simple=self.simple,
            sort=self.sort,
            starred=self.starred,
            statistics=self.statistics,
            visibility=self.visibility,
            with_custom_attributes=self.with_custom_attributes,
            with_issues_enabled=self.with_issues_enabled,
            with_merge_requests_enabled=self.with_merge_requests_enabled,
            with_programming_language=self.with_programming_language,
            with_shared=self.with_shared)

def get_projects(archived=None,group_id=None,include_subgroups=None,max_queryable_pages=None,membership=None,min_access_level=None,order_by=None,owned=None,page=None,per_page=None,search=None,simple=None,sort=None,starred=None,statistics=None,visibility=None,with_custom_attributes=None,with_issues_enabled=None,with_merge_requests_enabled=None,with_programming_language=None,with_shared=None,opts=None):
    """
    Provides details about a list of projects in the Gitlab provider. Listing all projects and group projects with [project filtering](https://docs.gitlab.com/ee/api/projects.html#list-user-projects) or [group project filtering](https://docs.gitlab.com/ee/api/groups.html#list-a-groups-projects) is supported.

    > NOTE: This data source supports all available filters exposed by the `xanzy/go-gitlab` package, which might not expose all available filters exposed by the Gitlab APIs.

    ## Example Usage
    ### List projects within a group tree

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    mygroup = gitlab.get_group(full_path="mygroup")
    group_projects = gitlab.get_projects(group_id=mygroup.id,
        order_by="name",
        include_subgroups=True,
        with_shared=False)
    ```
    ### List projects using the search syntax

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    projects = gitlab.get_projects(search="postgresql",
        visibility="private")
    ```


    :param bool archived: Limit by archived status.
    :param float group_id: The ID of the group owned by the authenticated user to look projects for within. Cannot be used with `min_access_level`, `with_programming_language` or `statistics`.
    :param bool include_subgroups: Include projects in subgroups of this group. Default is `false`. Needs `group_id`.
    :param float max_queryable_pages: Prevents overloading your Gitlab instance in case of a misconfiguration. Default is `10`.
    :param bool membership: Limit by projects that the current user is a member of.
    :param float min_access_level: Limit to projects where current user has at least this access level, refer to the [official documentation](https://docs.gitlab.com/ee/api/members.html) for values. Cannot be used with `group_id`.
    :param str order_by: Return projects ordered by `id`, `name`, `path`, `created_at`, `updated_at`, or `last_activity_at` fields. Default is `created_at`.
    :param bool owned: Limit by projects owned by the current user.
    :param str search: Return list of authorized projects matching the search criteria.
    :param bool simple: Return only the ID, URL, name, and path of each project.
    :param str sort: Return projects sorted in `asc` or `desc` order. Default is `desc`.
    :param bool starred: Limit by projects starred by the current user.
    :param bool statistics: Include project statistics. Cannot be used with `group_id`.
    :param str visibility: Limit by visibility `public`, `internal`, or `private`.
    :param bool with_custom_attributes: Include custom attributes in response _(admins only)_.
    :param bool with_issues_enabled: Limit by projects with issues feature enabled. Default is `false`.
    :param bool with_merge_requests_enabled: Limit by projects with merge requests feature enabled. Default is `false`.
    :param str with_programming_language: Limit by projects which use the given programming language. Cannot be used with `group_id`.
    :param bool with_shared: Include projects shared to this group. Default is `true`. Needs `group_id`.
    """
    __args__ = dict()


    __args__['archived'] = archived
    __args__['groupId'] = group_id
    __args__['includeSubgroups'] = include_subgroups
    __args__['maxQueryablePages'] = max_queryable_pages
    __args__['membership'] = membership
    __args__['minAccessLevel'] = min_access_level
    __args__['orderBy'] = order_by
    __args__['owned'] = owned
    __args__['page'] = page
    __args__['perPage'] = per_page
    __args__['search'] = search
    __args__['simple'] = simple
    __args__['sort'] = sort
    __args__['starred'] = starred
    __args__['statistics'] = statistics
    __args__['visibility'] = visibility
    __args__['withCustomAttributes'] = with_custom_attributes
    __args__['withIssuesEnabled'] = with_issues_enabled
    __args__['withMergeRequestsEnabled'] = with_merge_requests_enabled
    __args__['withProgrammingLanguage'] = with_programming_language
    __args__['withShared'] = with_shared
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = utilities.get_version()
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjects:getProjects', __args__, opts=opts).value

    return AwaitableGetProjectsResult(
        archived=__ret__.get('archived'),
        group_id=__ret__.get('groupId'),
        id=__ret__.get('id'),
        include_subgroups=__ret__.get('includeSubgroups'),
        max_queryable_pages=__ret__.get('maxQueryablePages'),
        membership=__ret__.get('membership'),
        min_access_level=__ret__.get('minAccessLevel'),
        order_by=__ret__.get('orderBy'),
        owned=__ret__.get('owned'),
        page=__ret__.get('page'),
        per_page=__ret__.get('perPage'),
        projects=__ret__.get('projects'),
        search=__ret__.get('search'),
        simple=__ret__.get('simple'),
        sort=__ret__.get('sort'),
        starred=__ret__.get('starred'),
        statistics=__ret__.get('statistics'),
        visibility=__ret__.get('visibility'),
        with_custom_attributes=__ret__.get('withCustomAttributes'),
        with_issues_enabled=__ret__.get('withIssuesEnabled'),
        with_merge_requests_enabled=__ret__.get('withMergeRequestsEnabled'),
        with_programming_language=__ret__.get('withProgrammingLanguage'),
        with_shared=__ret__.get('withShared'))
